Class: Google::Apis::SaasservicemgmtV1beta1::AppParams

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb

Overview

AppParams contains the parameters for creating an AppHub Application.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AppParams

Returns a new instance of AppParams.



134
135
136
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 134

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#groupString

Grouping used to construct the name of the AppHub Application. Multiple UnitKinds can specify the same group to use the same Application across their respective units. Corresponds to the app_boundary_id in the ADC composite ApplicationTemplate. Defaults to UnitKind.name Corresponds to the JSON property group

Returns:

  • (String)


127
128
129
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 127

def group
  @group
end

#scopeGoogle::Apis::SaasservicemgmtV1beta1::Scope

Scope of an application. Corresponds to the JSON property scope



132
133
134
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 132

def scope
  @scope
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



139
140
141
142
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 139

def update!(**args)
  @group = args[:group] if args.key?(:group)
  @scope = args[:scope] if args.key?(:scope)
end