Class: Google::Apis::SaasservicemgmtV1beta1::ErrorBudget

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb

Overview

The configuration for error budget. If the number of failed units exceeds max( allowed_count, allowed_ratio * total_units), the rollout will be paused.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ErrorBudget

Returns a new instance of ErrorBudget.



321
322
323
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 321

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_countFixnum

Optional. The maximum number of failed units allowed in a location without pausing the rollout. Corresponds to the JSON property allowedCount

Returns:

  • (Fixnum)


313
314
315
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 313

def allowed_count
  @allowed_count
end

#allowed_percentageFixnum

Optional. The maximum percentage of units allowed to fail (0, 100] within a location without pausing the rollout. Corresponds to the JSON property allowedPercentage

Returns:

  • (Fixnum)


319
320
321
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 319

def allowed_percentage
  @allowed_percentage
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



326
327
328
329
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 326

def update!(**args)
  @allowed_count = args[:allowed_count] if args.key?(:allowed_count)
  @allowed_percentage = args[:allowed_percentage] if args.key?(:allowed_percentage)
end