Class: Google::Apis::SaasservicemgmtV1beta1::Flag

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb

Overview

Represents a single Flag.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Flag

Returns a new instance of Flag.



583
584
585
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 583

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Annotations is an unstructured key-value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects. More info: https://kubernetes.io/docs/user-guide/annotations Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


493
494
495
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 493

def annotations
  @annotations
end

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


498
499
500
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 498

def create_time
  @create_time
end

#descriptionString

Optional. Description of the flag. Max length: 500 bytes. Corresponds to the JSON property description

Returns:

  • (String)


503
504
505
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 503

def description
  @description
end

#etagString

Output only. An opaque value that uniquely identifies a version or generation of a resource. It can be used to confirm that the client and server agree on the ordering of a resource being written. Corresponds to the JSON property etag

Returns:

  • (String)


510
511
512
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 510

def etag
  @etag
end

#evaluation_specGoogle::Apis::SaasservicemgmtV1beta1::EvaluationSpec

EvaluationSpec holds rules for evaluating the value of a flag. Corresponds to the JSON property evaluationSpec



515
516
517
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 515

def evaluation_spec
  @evaluation_spec
end

#flag_setString

Optional. Flag set this flag belongs to. Corresponds to the JSON property flagSet

Returns:

  • (String)


520
521
522
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 520

def flag_set
  @flag_set
end

#flag_value_typeString

Optional. Immutable. Flag value type. Corresponds to the JSON property flagValueType

Returns:

  • (String)


525
526
527
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 525

def flag_value_type
  @flag_value_type
end

#keyString

Required. Immutable. Flag key used in runtime evaluation APIs (OpenFeature). Max length: 256 bytes. Corresponds to the JSON property key

Returns:

  • (String)


531
532
533
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 531

def key
  @key
end

#labelsHash<String,String>

Optional. The labels on the resource, which can be used for categorization. similar to Kubernetes resource labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


537
538
539
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 537

def labels
  @labels
end

#nameString

Identifier. The resource name (full URI of the resource) following the standard naming scheme: "projects/project/locations/location/flags/ flag_id" Corresponds to the JSON property name

Returns:

  • (String)


544
545
546
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 544

def name
  @name
end

#stateString

Optional. Current state of the flag. Corresponds to the JSON property state

Returns:

  • (String)


549
550
551
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 549

def state
  @state
end

#uidString

Output only. The unique identifier of the resource. UID is unique in the time and space for this resource within the scope of the service. It is typically generated by the server on successful creation of a resource and must not be changed. UID is used to uniquely identify resources with resource name reuses. This should be a UUID4. Corresponds to the JSON property uid

Returns:

  • (String)


558
559
560
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 558

def uid
  @uid
end

#unit_kindString

Required. Immutable. UnitKind that can consume this flag. Corresponds to the JSON property unitKind

Returns:

  • (String)


563
564
565
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 563

def unit_kind
  @unit_kind
end

#update_timeString

Output only. The timestamp when the resource was last updated. Any change to the resource made by users must refresh this value. Changes to a resource made by the service should refresh this value. Corresponds to the JSON property updateTime

Returns:

  • (String)


570
571
572
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 570

def update_time
  @update_time
end

#value_typeString

Optional. Immutable. Deprecated: Use flag_value_type instead. Flag value type. Corresponds to the JSON property valueType

Returns:

  • (String)


576
577
578
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 576

def value_type
  @value_type
end

#variantsArray<Google::Apis::SaasservicemgmtV1beta1::FlagVariant>

Optional. A list of variants. Corresponds to the JSON property variants



581
582
583
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 581

def variants
  @variants
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 588

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @evaluation_spec = args[:evaluation_spec] if args.key?(:evaluation_spec)
  @flag_set = args[:flag_set] if args.key?(:flag_set)
  @flag_value_type = args[:flag_value_type] if args.key?(:flag_value_type)
  @key = args[:key] if args.key?(:key)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @uid = args[:uid] if args.key?(:uid)
  @unit_kind = args[:unit_kind] if args.key?(:unit_kind)
  @update_time = args[:update_time] if args.key?(:update_time)
  @value_type = args[:value_type] if args.key?(:value_type)
  @variants = args[:variants] if args.key?(:variants)
end