Class: Google::Apis::SaasservicemgmtV1beta1::FlagRevision

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb

Overview

A snapshot of the EvaluationSpec for the Flag.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FlagRevision

Returns a new instance of FlagRevision.



902
903
904
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 902

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Annotations is an unstructured key-value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects. More info: https://kubernetes.io/docs/user-guide/annotations Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


844
845
846
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 844

def annotations
  @annotations
end

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


849
850
851
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 849

def create_time
  @create_time
end

#etagString

Output only. An opaque value that uniquely identifies a version or generation of a resource. It can be used to confirm that the client and server agree on the ordering of a resource being written. Corresponds to the JSON property etag

Returns:

  • (String)


856
857
858
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 856

def etag
  @etag
end

#evaluation_specGoogle::Apis::SaasservicemgmtV1beta1::EvaluationSpec

EvaluationSpec holds rules for evaluating the value of a flag. Corresponds to the JSON property evaluationSpec



861
862
863
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 861

def evaluation_spec
  @evaluation_spec
end

#flagString

Required. Immutable. Name of the Flag this is a revision of. Corresponds to the JSON property flag

Returns:

  • (String)


866
867
868
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 866

def flag
  @flag
end

#labelsHash<String,String>

Optional. The labels on the resource, which can be used for categorization. similar to Kubernetes resource labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


872
873
874
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 872

def labels
  @labels
end

#nameString

Identifier. The resource name (full URI of the resource) following the standard naming scheme: "projects/project/locations/location/flagRevisions/ flag_revision_id" Corresponds to the JSON property name

Returns:

  • (String)


879
880
881
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 879

def name
  @name
end

#snapshotGoogle::Apis::SaasservicemgmtV1beta1::Flag

Represents a single Flag. Corresponds to the JSON property snapshot



884
885
886
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 884

def snapshot
  @snapshot
end

#uidString

Output only. The unique identifier of the resource. UID is unique in the time and space for this resource within the scope of the service. It is typically generated by the server on successful creation of a resource and must not be changed. UID is used to uniquely identify resources with resource name reuses. This should be a UUID4. Corresponds to the JSON property uid

Returns:

  • (String)


893
894
895
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 893

def uid
  @uid
end

#update_timeString

Output only. The timestamp when the resource was last updated. Any change to the resource made by users must refresh this value. Changes to a resource made by the service should refresh this value. Corresponds to the JSON property updateTime

Returns:

  • (String)


900
901
902
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 900

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



907
908
909
910
911
912
913
914
915
916
917
918
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 907

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @create_time = args[:create_time] if args.key?(:create_time)
  @etag = args[:etag] if args.key?(:etag)
  @evaluation_spec = args[:evaluation_spec] if args.key?(:evaluation_spec)
  @flag = args[:flag] if args.key?(:flag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @snapshot = args[:snapshot] if args.key?(:snapshot)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end