Class: Google::Apis::SaasservicemgmtV1beta1::FromMapping

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb

Overview

Output variables whose values will be passed on to dependencies

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FromMapping

Returns a new instance of FromMapping.



1008
1009
1010
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1008

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dependencyString

Required. Alias of the dependency that the outputVariable will pass its value to Corresponds to the JSON property dependency

Returns:

  • (String)


1001
1002
1003
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1001

def dependency
  @dependency
end

#output_variableString

Required. Name of the outputVariable on the dependency Corresponds to the JSON property outputVariable

Returns:

  • (String)


1006
1007
1008
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1006

def output_variable
  @output_variable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1013
1014
1015
1016
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1013

def update!(**args)
  @dependency = args[:dependency] if args.key?(:dependency)
  @output_variable = args[:output_variable] if args.key?(:output_variable)
end