Class: Google::Apis::SaasservicemgmtV1beta1::GoogleCloudLocationLocation
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1beta1::GoogleCloudLocationLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb
Overview
A resource that represents a Google Cloud location.
Instance Attribute Summary collapse
-
#display_name ⇒ String
The friendly name for this location, typically a nearby city name.
-
#labels ⇒ Hash<String,String>
Cross-service attributes for the location.
-
#location_id ⇒ String
The canonical id for this location.
-
#metadata ⇒ Hash<String,Object>
Service-specific metadata.
-
#name ⇒ String
Resource name for the location, which may vary between implementations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudLocationLocation
constructor
A new instance of GoogleCloudLocationLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudLocationLocation
Returns a new instance of GoogleCloudLocationLocation.
1026 1027 1028 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1026 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
The friendly name for this location, typically a nearby city name. For example,
"Tokyo".
Corresponds to the JSON property displayName
1001 1002 1003 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1001 def display_name @display_name end |
#labels ⇒ Hash<String,String>
Cross-service attributes for the location. For example "cloud.googleapis.com/
region": "us-east1"
Corresponds to the JSON property labels
1007 1008 1009 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1007 def labels @labels end |
#location_id ⇒ String
The canonical id for this location. For example: "us-east1".
Corresponds to the JSON property locationId
1012 1013 1014 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1012 def location_id @location_id end |
#metadata ⇒ Hash<String,Object>
Service-specific metadata. For example the available capacity at the given
location.
Corresponds to the JSON property metadata
1018 1019 1020 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1018 def @metadata end |
#name ⇒ String
Resource name for the location, which may vary between implementations. For
example: "projects/example-project/locations/us-east1"
Corresponds to the JSON property name
1024 1025 1026 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1024 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1031 1032 1033 1034 1035 1036 1037 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1031 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @labels = args[:labels] if args.key?(:labels) @location_id = args[:location_id] if args.key?(:location_id) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) end |