Class: Google::Apis::SaasservicemgmtV1beta1::ListFlagReleasesResponse
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1beta1::ListFlagReleasesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb
Overview
The response structure for the ListFlagReleases method.
Instance Attribute Summary collapse
-
#flag_releases ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::FlagRelease>
The resulting flag releases.
-
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent ListFlagReleases call to list the next page.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListFlagReleasesResponse
constructor
A new instance of ListFlagReleasesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListFlagReleasesResponse
Returns a new instance of ListFlagReleasesResponse.
1163 1164 1165 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1163 def initialize(**args) update!(**args) end |
Instance Attribute Details
#flag_releases ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::FlagRelease>
The resulting flag releases.
Corresponds to the JSON property flagReleases
1150 1151 1152 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1150 def flag_releases @flag_releases end |
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent
ListFlagReleases call to list the next page. If empty, there are no more pages.
Corresponds to the JSON property nextPageToken
1156 1157 1158 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1156 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1161 1162 1163 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1161 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1168 1169 1170 1171 1172 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1168 def update!(**args) @flag_releases = args[:flag_releases] if args.key?(:flag_releases) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |