Class: Google::Apis::SaasservicemgmtV1beta1::ListFlagsResponse
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1beta1::ListFlagsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb
Overview
The response structure for the ListFlags method.
Instance Attribute Summary collapse
-
#flags ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::Flag>
The resulting flags.
-
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent ListFlags call to list the next page.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListFlagsResponse
constructor
A new instance of ListFlagsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListFlagsResponse
Returns a new instance of ListFlagsResponse.
1158 1159 1160 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1158 def initialize(**args) update!(**args) end |
Instance Attribute Details
#flags ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::Flag>
The resulting flags.
Corresponds to the JSON property flags
1145 1146 1147 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1145 def flags @flags end |
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent ListFlags call
to list the next page. If empty, there are no more pages.
Corresponds to the JSON property nextPageToken
1151 1152 1153 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1151 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1156 1157 1158 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1156 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1163 1164 1165 1166 1167 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1163 def update!(**args) @flags = args[:flags] if args.key?(:flags) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |