Class: Google::Apis::SaasservicemgmtV1beta1::ListReleasesResponse
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1beta1::ListReleasesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb
Overview
The response structure for the ListReleases method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent ListReleases call to list the next page.
-
#releases ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::Release>
The resulting releases.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListReleasesResponse
constructor
A new instance of ListReleasesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListReleasesResponse
Returns a new instance of ListReleasesResponse.
1215 1216 1217 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1215 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent ListReleases
call to list the next page. If empty, there are no more pages.
Corresponds to the JSON property nextPageToken
1203 1204 1205 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1203 def next_page_token @next_page_token end |
#releases ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::Release>
The resulting releases.
Corresponds to the JSON property releases
1208 1209 1210 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1208 def releases @releases end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1213 1214 1215 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1213 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1220 1221 1222 1223 1224 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1220 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @releases = args[:releases] if args.key?(:releases) @unreachable = args[:unreachable] if args.key?(:unreachable) end |