Class: Google::Apis::SaasservicemgmtV1beta1::ListRolloutKindsResponse
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1beta1::ListRolloutKindsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb
Overview
The response structure for the ListRolloutKinds method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent ListRolloutKinds call to list the next page.
-
#rollout_kinds ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::RolloutKind>
The resulting rollout kinds.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListRolloutKindsResponse
constructor
A new instance of ListRolloutKindsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListRolloutKindsResponse
Returns a new instance of ListRolloutKindsResponse.
1317 1318 1319 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1317 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent
ListRolloutKinds call to list the next page. If empty, there are no more pages.
Corresponds to the JSON property nextPageToken
1305 1306 1307 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1305 def next_page_token @next_page_token end |
#rollout_kinds ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::RolloutKind>
The resulting rollout kinds.
Corresponds to the JSON property rolloutKinds
1310 1311 1312 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1310 def rollout_kinds @rollout_kinds end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1315 1316 1317 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1315 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1322 1323 1324 1325 1326 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1322 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @rollout_kinds = args[:rollout_kinds] if args.key?(:rollout_kinds) @unreachable = args[:unreachable] if args.key?(:unreachable) end |