Class: Google::Apis::SaasservicemgmtV1beta1::ListRolloutsResponse
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1beta1::ListRolloutsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb
Overview
The response structure for the ListRollouts method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent ListRollouts call to list the next page.
-
#rollouts ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::Rollout>
The resulting rollouts.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListRolloutsResponse
constructor
A new instance of ListRolloutsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListRolloutsResponse
Returns a new instance of ListRolloutsResponse.
1305 1306 1307 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1305 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent ListRollouts
call to list the next page. If empty, there are no more pages.
Corresponds to the JSON property nextPageToken
1293 1294 1295 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1293 def next_page_token @next_page_token end |
#rollouts ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::Rollout>
The resulting rollouts.
Corresponds to the JSON property rollouts
1298 1299 1300 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1298 def rollouts @rollouts end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1303 1304 1305 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1303 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1310 1311 1312 1313 1314 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1310 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @rollouts = args[:rollouts] if args.key?(:rollouts) @unreachable = args[:unreachable] if args.key?(:unreachable) end |