Class: Google::Apis::SaasservicemgmtV1beta1::ListTenantsResponse
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1beta1::ListTenantsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb
Overview
The response structure for the ListTenants method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent ListTenants call to list the next page.
-
#tenants ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::Tenant>
The resulting tenants.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListTenantsResponse
constructor
A new instance of ListTenantsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListTenantsResponse
Returns a new instance of ListTenantsResponse.
1343 1344 1345 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1343 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent ListTenants
call to list the next page. If empty, there are no more pages.
Corresponds to the JSON property nextPageToken
1331 1332 1333 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1331 def next_page_token @next_page_token end |
#tenants ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::Tenant>
The resulting tenants.
Corresponds to the JSON property tenants
1336 1337 1338 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1336 def tenants @tenants end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1341 1342 1343 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1341 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1348 1349 1350 1351 1352 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1348 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @tenants = args[:tenants] if args.key?(:tenants) @unreachable = args[:unreachable] if args.key?(:unreachable) end |