Class: Google::Apis::SaasservicemgmtV1beta1::ListUnitGroupOperationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1beta1::ListUnitGroupOperationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb
Overview
The response structure for the ListUnitGroupOperations method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent ListUnitGroupOperations call to list the next page.
-
#unit_group_operations ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::UnitGroupOperation>
The resulting unit group operations.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListUnitGroupOperationsResponse
constructor
A new instance of ListUnitGroupOperationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListUnitGroupOperationsResponse
Returns a new instance of ListUnitGroupOperationsResponse.
1478 1479 1480 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1478 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent
ListUnitGroupOperations call to list the next page. If empty, there are no
more pages.
Corresponds to the JSON property nextPageToken
1466 1467 1468 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1466 def next_page_token @next_page_token end |
#unit_group_operations ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::UnitGroupOperation>
The resulting unit group operations.
Corresponds to the JSON property unitGroupOperations
1471 1472 1473 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1471 def unit_group_operations @unit_group_operations end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1476 1477 1478 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1476 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1483 1484 1485 1486 1487 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1483 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unit_group_operations = args[:unit_group_operations] if args.key?(:unit_group_operations) @unreachable = args[:unreachable] if args.key?(:unreachable) end |