Class: Google::Apis::SaasservicemgmtV1beta1::Provision

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb

Overview

Provision is the unit operation that provision the underlying resources represented by a Unit. Can only execute if the Unit is not currently provisioned.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Provision

Returns a new instance of Provision.



1511
1512
1513
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1511

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#input_variablesArray<Google::Apis::SaasservicemgmtV1beta1::UnitVariable>

Optional. Set of input variables. Maximum 100. (optional) Corresponds to the JSON property inputVariables



1504
1505
1506
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1504

def input_variables
  @input_variables
end

#releaseString

Optional. Reference to the Release object to use for the Unit. (optional). Corresponds to the JSON property release

Returns:

  • (String)


1509
1510
1511
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1509

def release
  @release
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1516
1517
1518
1519
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1516

def update!(**args)
  @input_variables = args[:input_variables] if args.key?(:input_variables)
  @release = args[:release] if args.key?(:release)
end