Class: Google::Apis::SaasservicemgmtV1beta1::RolloutControl
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1beta1::RolloutControl
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb
Overview
RolloutControl provides a way to request a change to the execution of a Rollout by pausing or canceling it.
Instance Attribute Summary collapse
-
#action ⇒ String
Required.
-
#run_params ⇒ Google::Apis::SaasservicemgmtV1beta1::RunRolloutActionParams
Parameters for the RUN action controlling the behavior of the rollout when it is resumed from a PAUSED state.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutControl
constructor
A new instance of RolloutControl.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutControl
Returns a new instance of RolloutControl.
2043 2044 2045 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2043 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
Required. Action to be performed on the Rollout. The default behavior is to
run the rollout until it naturally reaches a terminal state.
Corresponds to the JSON property action
2035 2036 2037 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2035 def action @action end |
#run_params ⇒ Google::Apis::SaasservicemgmtV1beta1::RunRolloutActionParams
Parameters for the RUN action controlling the behavior of the rollout when it
is resumed from a PAUSED state.
Corresponds to the JSON property runParams
2041 2042 2043 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2041 def run_params @run_params end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2048 2049 2050 2051 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2048 def update!(**args) @action = args[:action] if args.key?(:action) @run_params = args[:run_params] if args.key?(:run_params) end |