Class: Google::Apis::SaasservicemgmtV1beta1::RolloutStats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb

Overview

RolloutStats contains information about the progress of a rollout.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutStats

Returns a new instance of RolloutStats.



2193
2194
2195
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2193

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#estimated_total_unit_countFixnum

Optional. Output only. Estimated number of units based. The estimation is computed upon creation of the rollout. Corresponds to the JSON property estimatedTotalUnitCount

Returns:

  • (Fixnum)


2181
2182
2183
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2181

def estimated_total_unit_count
  @estimated_total_unit_count
end

#operations_by_stateArray<Google::Apis::SaasservicemgmtV1beta1::Aggregate>

Optional. Output only. Unordered list. A breakdown of the progress of operations triggered by the rollout. Provides a count of Operations by their state. This can be used to determine the number of units which have been updated, or are scheduled to be updated. There will be at most one entry per group. Possible values for operation groups are: - "SCHEDULED" - "PENDING" - " RUNNING" - "SUCCEEDED" - "FAILED" - "CANCELLED" Corresponds to the JSON property operationsByState



2191
2192
2193
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2191

def operations_by_state
  @operations_by_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2198
2199
2200
2201
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2198

def update!(**args)
  @estimated_total_unit_count = args[:estimated_total_unit_count] if args.key?(:estimated_total_unit_count)
  @operations_by_state = args[:operations_by_state] if args.key?(:operations_by_state)
end