Class: Google::Apis::SaasservicemgmtV1beta1::SaasCondition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb

Overview

SaasCondition describes the status of a Saas.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SaasCondition

Returns a new instance of SaasCondition.



2369
2370
2371
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2369

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_transition_timeString

Required. Last time the condition transited from one status to another. Corresponds to the JSON property lastTransitionTime

Returns:

  • (String)


2347
2348
2349
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2347

def last_transition_time
  @last_transition_time
end

#messageString

Required. Human readable message indicating details about the last transition. Corresponds to the JSON property message

Returns:

  • (String)


2352
2353
2354
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2352

def message
  @message
end

#reasonString

Required. Brief reason for the condition's last transition. Corresponds to the JSON property reason

Returns:

  • (String)


2357
2358
2359
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2357

def reason
  @reason
end

#statusString

Required. Status of the condition. Corresponds to the JSON property status

Returns:

  • (String)


2362
2363
2364
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2362

def status
  @status
end

#typeString

Required. Type of the condition. Corresponds to the JSON property type

Returns:

  • (String)


2367
2368
2369
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2367

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2374
2375
2376
2377
2378
2379
2380
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2374

def update!(**args)
  @last_transition_time = args[:last_transition_time] if args.key?(:last_transition_time)
  @message = args[:message] if args.key?(:message)
  @reason = args[:reason] if args.key?(:reason)
  @status = args[:status] if args.key?(:status)
  @type = args[:type] if args.key?(:type)
end