Class: Google::Apis::SaasservicemgmtV1beta1::SaasRelease

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb

Overview

SaasRelease is a collection of Releases that are assigned to a UnitGroup. It allows provisioning and updates of UnitGroup, which contains multiple Units of different UnitKinds.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SaasRelease

Returns a new instance of SaasRelease.



2438
2439
2440
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2438

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Annotations is an unstructured key-value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects. More info: https://kubernetes.io/docs/user-guide/annotations Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


2395
2396
2397
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2395

def annotations
  @annotations
end

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2400
2401
2402
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2400

def create_time
  @create_time
end

#etagString

Output only. An opaque value that uniquely identifies a version or generation of a resource. It can be used to confirm that the client and server agree on the ordering of a resource being written. Corresponds to the JSON property etag

Returns:

  • (String)


2407
2408
2409
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2407

def etag
  @etag
end

#labelsHash<String,String>

Optional. The labels on the resource, which can be used for categorization. similar to Kubernetes resource labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2413
2414
2415
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2413

def labels
  @labels
end

#nameString

Identifier. The resource name (full URI of the resource) following the standard naming scheme: "projects/project/locations/location/saasReleases/ saasRelease" Corresponds to the JSON property name

Returns:

  • (String)


2420
2421
2422
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2420

def name
  @name
end

#uidString

Output only. The unique identifier of the resource. UID is unique in the time and space for this resource within the scope of the service. It is typically generated by the server on successful creation of a resource and must not be changed. UID is used to uniquely identify resources with resource name reuses. This should be a UUID4. Corresponds to the JSON property uid

Returns:

  • (String)


2429
2430
2431
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2429

def uid
  @uid
end

#update_timeString

Output only. The timestamp when the resource was last updated. Any change to the resource made by users must refresh this value. Changes to a resource made by the service should refresh this value. Corresponds to the JSON property updateTime

Returns:

  • (String)


2436
2437
2438
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2436

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2443
2444
2445
2446
2447
2448
2449
2450
2451
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2443

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @create_time = args[:create_time] if args.key?(:create_time)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end