Class: Google::Apis::SaasservicemgmtV1beta1::ToMapping

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb

Overview

Input variables whose values will be passed on to dependencies

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ToMapping

Returns a new instance of ToMapping.



2425
2426
2427
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2425

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dependencyString

Required. Alias of the dependency that the inputVariable will pass its value to Corresponds to the JSON property dependency

Returns:

  • (String)


2411
2412
2413
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2411

def dependency
  @dependency
end

#ignore_for_lookupBoolean Also known as: ignore_for_lookup?

Optional. Tells App Lifecycle Manager if this mapping should be used during lookup or not Corresponds to the JSON property ignoreForLookup

Returns:

  • (Boolean)


2417
2418
2419
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2417

def ignore_for_lookup
  @ignore_for_lookup
end

#input_variableString

Required. Name of the inputVariable on the dependency Corresponds to the JSON property inputVariable

Returns:

  • (String)


2423
2424
2425
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2423

def input_variable
  @input_variable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2430
2431
2432
2433
2434
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2430

def update!(**args)
  @dependency = args[:dependency] if args.key?(:dependency)
  @ignore_for_lookup = args[:ignore_for_lookup] if args.key?(:ignore_for_lookup)
  @input_variable = args[:input_variable] if args.key?(:input_variable)
end