Class: Google::Apis::SaasservicemgmtV1beta1::UnitCondition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb

Overview

UnitCondition describes the status of an Unit. UnitCondition is individual components that contribute to an overall state.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UnitCondition

Returns a new instance of UnitCondition.



2660
2661
2662
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2660

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_transition_timeString

Required. Last time the condition transited from one status to another. Corresponds to the JSON property lastTransitionTime

Returns:

  • (String)


2638
2639
2640
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2638

def last_transition_time
  @last_transition_time
end

#messageString

Required. Human readable message indicating details about the last transition. Corresponds to the JSON property message

Returns:

  • (String)


2643
2644
2645
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2643

def message
  @message
end

#reasonString

Required. Brief reason for the condition's last transition. Corresponds to the JSON property reason

Returns:

  • (String)


2648
2649
2650
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2648

def reason
  @reason
end

#statusString

Required. Status of the condition. Corresponds to the JSON property status

Returns:

  • (String)


2653
2654
2655
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2653

def status
  @status
end

#typeString

Required. Type of the condition. Corresponds to the JSON property type

Returns:

  • (String)


2658
2659
2660
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2658

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2665
2666
2667
2668
2669
2670
2671
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2665

def update!(**args)
  @last_transition_time = args[:last_transition_time] if args.key?(:last_transition_time)
  @message = args[:message] if args.key?(:message)
  @reason = args[:reason] if args.key?(:reason)
  @status = args[:status] if args.key?(:status)
  @type = args[:type] if args.key?(:type)
end