Class: Google::Apis::SaasservicemgmtV1beta1::UnitKind

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb

Overview

Definition of a Unit. Units belonging to the same UnitKind are managed together; for example they follow the same release model (blueprints, versions etc.) and are typically rolled out together.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UnitKind

Returns a new instance of UnitKind.



3200
3201
3202
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3200

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Annotations is an unstructured key-value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects. More info: https://kubernetes.io/docs/user-guide/annotations Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


3102
3103
3104
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3102

def annotations
  @annotations
end

#app_paramsGoogle::Apis::SaasservicemgmtV1beta1::AppParams

AppParams contains the parameters for creating an AppHub Application. Corresponds to the JSON property appParams



3107
3108
3109
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3107

def app_params
  @app_params
end

#application_template_componentGoogle::Apis::SaasservicemgmtV1beta1::ComponentRef

ComponentRef represents a reference to a component resource. Next ID: 4 Corresponds to the JSON property applicationTemplateComponent



3112
3113
3114
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3112

def application_template_component
  @application_template_component
end

#boundary_typeString

Optional. Output only. BoundaryType describes the type of boundary the Unit Kind represents. Corresponds to the JSON property boundaryType

Returns:

  • (String)


3118
3119
3120
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3118

def boundary_type
  @boundary_type
end

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3123
3124
3125
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3123

def create_time
  @create_time
end

#default_flag_revisionsArray<String>

Optional. Default revisions of flags for this UnitKind. Newly created units will use the flag default_flag_revisions present at the time of creation. Corresponds to the JSON property defaultFlagRevisions

Returns:

  • (Array<String>)


3129
3130
3131
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3129

def default_flag_revisions
  @default_flag_revisions
end

#default_releaseString

Optional. A reference to the Release object to use as default for creating new units of this UnitKind (optional). If not specified, a new unit must explicitly reference which release to use for its creation. Corresponds to the JSON property defaultRelease

Returns:

  • (String)


3136
3137
3138
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3136

def default_release
  @default_release
end

#dependenciesArray<Google::Apis::SaasservicemgmtV1beta1::Dependency>

Optional. Immutable. List of other unit kinds that this release will depend on. Dependencies will be automatically provisioned if not found. Maximum 10. Corresponds to the JSON property dependencies



3142
3143
3144
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3142

def dependencies
  @dependencies
end

#etagString

Output only. An opaque value that uniquely identifies a version or generation of a resource. It can be used to confirm that the client and server agree on the ordering of a resource being written. Corresponds to the JSON property etag

Returns:

  • (String)


3149
3150
3151
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3149

def etag
  @etag
end

#input_variable_mappingsArray<Google::Apis::SaasservicemgmtV1beta1::VariableMapping>

Optional. List of inputVariables for this release that will either be retrieved from a dependency’s outputVariables, or will be passed on to a dependency’s inputVariables. Maximum 100. Corresponds to the JSON property inputVariableMappings



3156
3157
3158
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3156

def input_variable_mappings
  @input_variable_mappings
end

#labelsHash<String,String>

Optional. The labels on the resource, which can be used for categorization. similar to Kubernetes resource labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3162
3163
3164
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3162

def labels
  @labels
end

#nameString

Identifier. The resource name (full URI of the resource) following the standard naming scheme: "projects/project/locations/location/unitKinds/ unitKind" Corresponds to the JSON property name

Returns:

  • (String)


3169
3170
3171
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3169

def name
  @name
end

#output_variable_mappingsArray<Google::Apis::SaasservicemgmtV1beta1::VariableMapping>

Optional. List of outputVariables for this unit kind will be passed to this unit's outputVariables. Maximum 100. Corresponds to the JSON property outputVariableMappings



3175
3176
3177
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3175

def output_variable_mappings
  @output_variable_mappings
end

#saasString

Required. Immutable. A reference to the Saas that defines the product (managed service) that the producer wants to manage with App Lifecycle Manager. Part of the App Lifecycle Manager common data model. Immutable once set. Corresponds to the JSON property saas

Returns:

  • (String)


3182
3183
3184
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3182

def saas
  @saas
end

#uidString

Output only. The unique identifier of the resource. UID is unique in the time and space for this resource within the scope of the service. It is typically generated by the server on successful creation of a resource and must not be changed. UID is used to uniquely identify resources with resource name reuses. This should be a UUID4. Corresponds to the JSON property uid

Returns:

  • (String)


3191
3192
3193
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3191

def uid
  @uid
end

#update_timeString

Output only. The timestamp when the resource was last updated. Any change to the resource made by users must refresh this value. Changes to a resource made by the service should refresh this value. Corresponds to the JSON property updateTime

Returns:

  • (String)


3198
3199
3200
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3198

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3205
3206
3207
3208
3209
3210
3211
3212
3213
3214
3215
3216
3217
3218
3219
3220
3221
3222
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3205

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @app_params = args[:app_params] if args.key?(:app_params)
  @application_template_component = args[:application_template_component] if args.key?(:application_template_component)
  @boundary_type = args[:boundary_type] if args.key?(:boundary_type)
  @create_time = args[:create_time] if args.key?(:create_time)
  @default_flag_revisions = args[:default_flag_revisions] if args.key?(:default_flag_revisions)
  @default_release = args[:default_release] if args.key?(:default_release)
  @dependencies = args[:dependencies] if args.key?(:dependencies)
  @etag = args[:etag] if args.key?(:etag)
  @input_variable_mappings = args[:input_variable_mappings] if args.key?(:input_variable_mappings)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @output_variable_mappings = args[:output_variable_mappings] if args.key?(:output_variable_mappings)
  @saas = args[:saas] if args.key?(:saas)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end