Class: Google::Apis::SaasservicemgmtV1beta1::UnitOperationCondition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb

Overview

UnitOperationCondition describes the status of an Unit Operation. UnitOperationCondition is individual components that contribute to an overall state.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UnitOperationCondition

Returns a new instance of UnitOperationCondition.



3034
3035
3036
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3034

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_transition_timeString

Required. Last time the condition transited from one status to another. Corresponds to the JSON property lastTransitionTime

Returns:

  • (String)


3012
3013
3014
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3012

def last_transition_time
  @last_transition_time
end

#messageString

Required. Human readable message indicating details about the last transition. Corresponds to the JSON property message

Returns:

  • (String)


3017
3018
3019
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3017

def message
  @message
end

#reasonString

Required. Brief reason for the condition's last transition. Corresponds to the JSON property reason

Returns:

  • (String)


3022
3023
3024
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3022

def reason
  @reason
end

#statusString

Required. Status of the condition. Corresponds to the JSON property status

Returns:

  • (String)


3027
3028
3029
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3027

def status
  @status
end

#typeString

Required. Type of the condition. Corresponds to the JSON property type

Returns:

  • (String)


3032
3033
3034
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3032

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3039
3040
3041
3042
3043
3044
3045
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3039

def update!(**args)
  @last_transition_time = args[:last_transition_time] if args.key?(:last_transition_time)
  @message = args[:message] if args.key?(:message)
  @reason = args[:reason] if args.key?(:reason)
  @status = args[:status] if args.key?(:status)
  @type = args[:type] if args.key?(:type)
end