Class: Google::Apis::SaasservicemgmtV1beta1::Upgrade

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb

Overview

Upgrade is the unit operation that upgrades a provisioned unit, which may also include the underlying resources represented by a Unit. Can only execute if the Unit is currently provisioned.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Upgrade

Returns a new instance of Upgrade.



3524
3525
3526
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3524

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#input_variablesArray<Google::Apis::SaasservicemgmtV1beta1::UnitVariable>

Optional. Set of input variables. Maximum 100. (optional) Corresponds to the JSON property inputVariables



3517
3518
3519
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3517

def input_variables
  @input_variables
end

#releaseString

Optional. Reference to the Release object to use for the Unit. (optional). Corresponds to the JSON property release

Returns:

  • (String)


3522
3523
3524
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3522

def release
  @release
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3529
3530
3531
3532
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3529

def update!(**args)
  @input_variables = args[:input_variables] if args.key?(:input_variables)
  @release = args[:release] if args.key?(:release)
end