Class: Google::Apis::SaasservicemgmtV1beta1::VariableMapping

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb

Overview

Mapping of input variables to their respective output variable for depedenencies

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VariableMapping

Returns a new instance of VariableMapping.



3555
3556
3557
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3555

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fromGoogle::Apis::SaasservicemgmtV1beta1::FromMapping

Output variables whose values will be passed on to dependencies Corresponds to the JSON property from



3543
3544
3545
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3543

def from
  @from
end

#toGoogle::Apis::SaasservicemgmtV1beta1::ToMapping

Input variables whose values will be passed on to dependencies Corresponds to the JSON property to



3548
3549
3550
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3548

def to
  @to
end

#variableString

Required. name of the variable Corresponds to the JSON property variable

Returns:

  • (String)


3553
3554
3555
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3553

def variable
  @variable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3560
3561
3562
3563
3564
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3560

def update!(**args)
  @from = args[:from] if args.key?(:from)
  @to = args[:to] if args.key?(:to)
  @variable = args[:variable] if args.key?(:variable)
end