Class: Google::Apis::SaasservicemgmtV1beta1::Blueprint
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1beta1::Blueprint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb
Overview
Blueprints are OCI Images that contain all of the artifacts needed to provision a unit. Metadata such as, type of the engine used to actuate the blueprint (e.g. terraform, helm etc) and version will come from the image manifest. If the hostname is omitted, it will be assumed to be the regional path to Artifact Registry (eg. us-east1-docker.pkg.dev).
Instance Attribute Summary collapse
-
#engine ⇒ String
Output only.
-
#package ⇒ String
Optional.
-
#version ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Blueprint
constructor
A new instance of Blueprint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Blueprint
Returns a new instance of Blueprint.
170 171 172 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 170 def initialize(**args) update!(**args) end |
Instance Attribute Details
#engine ⇒ String
Output only. Type of the engine used to actuate the blueprint. e.g. terraform,
helm etc.
Corresponds to the JSON property engine
157 158 159 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 157 def engine @engine end |
#package ⇒ String
Optional. Immutable. URI to a blueprint used by the Unit (required unless
unitKind or release is set).
Corresponds to the JSON property package
163 164 165 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 163 def package @package end |
#version ⇒ String
Output only. Version metadata if present on the blueprint.
Corresponds to the JSON property version
168 169 170 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 168 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
175 176 177 178 179 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 175 def update!(**args) @engine = args[:engine] if args.key?(:engine) @package = args[:package] if args.key?(:package) @version = args[:version] if args.key?(:version) end |