Class: Google::Apis::SaasservicemgmtV1beta1::ComponentRef
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1beta1::ComponentRef
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb
Overview
ComponentRef represents a reference to a component resource. Next ID: 4
Instance Attribute Summary collapse
-
#component ⇒ String
Name of the component in composite.Components Corresponds to the JSON property
component. -
#composite_ref ⇒ Google::Apis::SaasservicemgmtV1beta1::CompositeRef
CompositeRef represents a reference to a composite resource.
-
#revision ⇒ String
Revision of the component.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ComponentRef
constructor
A new instance of ComponentRef.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ComponentRef
Returns a new instance of ComponentRef.
203 204 205 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 203 def initialize(**args) update!(**args) end |
Instance Attribute Details
#component ⇒ String
Name of the component in composite.Components
Corresponds to the JSON property component
189 190 191 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 189 def component @component end |
#composite_ref ⇒ Google::Apis::SaasservicemgmtV1beta1::CompositeRef
CompositeRef represents a reference to a composite resource. Next ID: 4
Corresponds to the JSON property compositeRef
194 195 196 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 194 def composite_ref @composite_ref end |
#revision ⇒ String
Revision of the component. If the component does not have a revision, this
field will be explicitly set to the revision of the composite
ApplicationTemplate.
Corresponds to the JSON property revision
201 202 203 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 201 def revision @revision end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
208 209 210 211 212 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 208 def update!(**args) @component = args[:component] if args.key?(:component) @composite_ref = args[:composite_ref] if args.key?(:composite_ref) @revision = args[:revision] if args.key?(:revision) end |