Class: Google::Apis::SaasservicemgmtV1beta1::EvaluationSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb

Overview

EvaluationSpec holds rules for evaluating the value of a flag.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EvaluationSpec

Returns a new instance of EvaluationSpec.



423
424
425
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 423

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allocationsArray<Google::Apis::SaasservicemgmtV1beta1::Allocation>

Optional. A list of allocations. Corresponds to the JSON property allocations



388
389
390
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 388

def allocations
  @allocations
end

#attributesArray<String>

Optional. Names of the context attributes that are used in the evaluation rules and allocations. Corresponds to the JSON property attributes

Returns:

  • (Array<String>)


394
395
396
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 394

def attributes
  @attributes
end

#default_allocationString

Optional. The ID of an allocation to use as the default. Corresponds to the JSON property defaultAllocation

Returns:

  • (String)


399
400
401
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 399

def default_allocation
  @default_allocation
end

#default_targetString

Optional. Deprecated: Use base_target instead. Default variant or allocation of the flag. Corresponds to the JSON property defaultTarget

Returns:

  • (String)


405
406
407
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 405

def default_target
  @default_target
end

#default_variantString

Optional. The name of a variant to use as the default. Corresponds to the JSON property defaultVariant

Returns:

  • (String)


410
411
412
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 410

def default_variant
  @default_variant
end

#rulesArray<Google::Apis::SaasservicemgmtV1beta1::EvaluationRule>

Optional. Evaluation rules define the logic for evaluating the flag against a given context. The rules are evaluated sequentially in their specified order. Corresponds to the JSON property rules



416
417
418
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 416

def rules
  @rules
end

#variantsArray<Google::Apis::SaasservicemgmtV1beta1::Variant>

Optional. A list of variants. Corresponds to the JSON property variants



421
422
423
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 421

def variants
  @variants
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



428
429
430
431
432
433
434
435
436
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 428

def update!(**args)
  @allocations = args[:allocations] if args.key?(:allocations)
  @attributes = args[:attributes] if args.key?(:attributes)
  @default_allocation = args[:default_allocation] if args.key?(:default_allocation)
  @default_target = args[:default_target] if args.key?(:default_target)
  @default_variant = args[:default_variant] if args.key?(:default_variant)
  @rules = args[:rules] if args.key?(:rules)
  @variants = args[:variants] if args.key?(:variants)
end