Class: Google::Apis::SaasservicemgmtV1beta1::EvaluationSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb

Overview

EvaluationSpec holds rules for evaluating the value of a flag.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EvaluationSpec

Returns a new instance of EvaluationSpec.



399
400
401
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 399

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allocationsArray<Google::Apis::SaasservicemgmtV1beta1::Allocation>

Optional. A list of allocations. Corresponds to the JSON property allocations



375
376
377
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 375

def allocations
  @allocations
end

#attributesArray<String>

Optional. Names of the context attributes that are used in the evaluation rules and allocations. Corresponds to the JSON property attributes

Returns:

  • (Array<String>)


381
382
383
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 381

def attributes
  @attributes
end

#default_targetString

Required. Default variant or allocation of the flag. Corresponds to the JSON property defaultTarget

Returns:

  • (String)


386
387
388
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 386

def default_target
  @default_target
end

#rulesArray<Google::Apis::SaasservicemgmtV1beta1::EvaluationRule>

Optional. Evaluation rules define the logic for evaluating the flag against a given context. The rules are evaluated sequentially in their specified order. Corresponds to the JSON property rules



392
393
394
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 392

def rules
  @rules
end

#variantsArray<Google::Apis::SaasservicemgmtV1beta1::Variant>

Optional. A list of variants. Corresponds to the JSON property variants



397
398
399
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 397

def variants
  @variants
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



404
405
406
407
408
409
410
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 404

def update!(**args)
  @allocations = args[:allocations] if args.key?(:allocations)
  @attributes = args[:attributes] if args.key?(:attributes)
  @default_target = args[:default_target] if args.key?(:default_target)
  @rules = args[:rules] if args.key?(:rules)
  @variants = args[:variants] if args.key?(:variants)
end