Class: Google::Apis::SaasservicemgmtV1beta1::Flag

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb

Overview

Represents a single Flag.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Flag

Returns a new instance of Flag.



513
514
515
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 513

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Annotations is an unstructured key-value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects. More info: https://kubernetes.io/docs/user-guide/annotations Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


423
424
425
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 423

def annotations
  @annotations
end

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


428
429
430
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 428

def create_time
  @create_time
end

#descriptionString

Optional. Description of the flag. Max length: 500 bytes. Corresponds to the JSON property description

Returns:

  • (String)


433
434
435
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 433

def description
  @description
end

#etagString

Output only. An opaque value that uniquely identifies a version or generation of a resource. It can be used to confirm that the client and server agree on the ordering of a resource being written. Corresponds to the JSON property etag

Returns:

  • (String)


440
441
442
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 440

def etag
  @etag
end

#evaluation_specGoogle::Apis::SaasservicemgmtV1beta1::EvaluationSpec

EvaluationSpec holds rules for evaluating the value of a flag. Corresponds to the JSON property evaluationSpec



445
446
447
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 445

def evaluation_spec
  @evaluation_spec
end

#flag_setString

Optional. Flag set this flag belongs to. Corresponds to the JSON property flagSet

Returns:

  • (String)


450
451
452
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 450

def flag_set
  @flag_set
end

#flag_value_typeString

Optional. Immutable. Flag value type. Corresponds to the JSON property flagValueType

Returns:

  • (String)


455
456
457
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 455

def flag_value_type
  @flag_value_type
end

#keyString

Required. Immutable. Flag key used in runtime evaluation APIs (OpenFeature). Max length: 256 bytes. Corresponds to the JSON property key

Returns:

  • (String)


461
462
463
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 461

def key
  @key
end

#labelsHash<String,String>

Optional. The labels on the resource, which can be used for categorization. similar to Kubernetes resource labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


467
468
469
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 467

def labels
  @labels
end

#nameString

Identifier. The resource name (full URI of the resource) following the standard naming scheme: "projects/project/locations/location/flags/ flag_id" Corresponds to the JSON property name

Returns:

  • (String)


474
475
476
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 474

def name
  @name
end

#stateString

Optional. Current state of the flag. Corresponds to the JSON property state

Returns:

  • (String)


479
480
481
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 479

def state
  @state
end

#uidString

Output only. The unique identifier of the resource. UID is unique in the time and space for this resource within the scope of the service. It is typically generated by the server on successful creation of a resource and must not be changed. UID is used to uniquely identify resources with resource name reuses. This should be a UUID4. Corresponds to the JSON property uid

Returns:

  • (String)


488
489
490
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 488

def uid
  @uid
end

#unit_kindString

Required. Immutable. UnitKind that can consume this flag. Corresponds to the JSON property unitKind

Returns:

  • (String)


493
494
495
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 493

def unit_kind
  @unit_kind
end

#update_timeString

Output only. The timestamp when the resource was last updated. Any change to the resource made by users must refresh this value. Changes to a resource made by the service should refresh this value. Corresponds to the JSON property updateTime

Returns:

  • (String)


500
501
502
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 500

def update_time
  @update_time
end

#value_typeString

Optional. Immutable. Deprecated: Use flag_value_type instead. Flag value type. Corresponds to the JSON property valueType

Returns:

  • (String)


506
507
508
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 506

def value_type
  @value_type
end

#variantsArray<Google::Apis::SaasservicemgmtV1beta1::FlagVariant>

Optional. A list of variants. Corresponds to the JSON property variants



511
512
513
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 511

def variants
  @variants
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 518

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @evaluation_spec = args[:evaluation_spec] if args.key?(:evaluation_spec)
  @flag_set = args[:flag_set] if args.key?(:flag_set)
  @flag_value_type = args[:flag_value_type] if args.key?(:flag_value_type)
  @key = args[:key] if args.key?(:key)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @uid = args[:uid] if args.key?(:uid)
  @unit_kind = args[:unit_kind] if args.key?(:unit_kind)
  @update_time = args[:update_time] if args.key?(:update_time)
  @value_type = args[:value_type] if args.key?(:value_type)
  @variants = args[:variants] if args.key?(:variants)
end