Class: Google::Apis::SaasservicemgmtV1beta1::FlagAttribute

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb

Overview

FlagAttribute defines a custom property in the evaluation context.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FlagAttribute

Returns a new instance of FlagAttribute.



609
610
611
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 609

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Annotations is an unstructured key-value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects. More info: https://kubernetes.io/docs/user-guide/annotations Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


548
549
550
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 548

def annotations
  @annotations
end

#attribute_value_typeString

Optional. Immutable. Type of the attribute. Corresponds to the JSON property attributeValueType

Returns:

  • (String)


553
554
555
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 553

def attribute_value_type
  @attribute_value_type
end

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


558
559
560
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 558

def create_time
  @create_time
end

#etagString

Output only. An opaque value that uniquely identifies a version or generation of a resource. It can be used to confirm that the client and server agree on the ordering of a resource being written. Corresponds to the JSON property etag

Returns:

  • (String)


565
566
567
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 565

def etag
  @etag
end

#keyString

Required. Immutable. The identifier for the attribute, used as the key in the evaluation context. The attribute key is referenced in the evaluation rules and used in the OpenFeature evaluation API to specify the attribute context. Corresponds to the JSON property key

Returns:

  • (String)


572
573
574
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 572

def key
  @key
end

#labelsHash<String,String>

Optional. The labels on the resource, which can be used for categorization. similar to Kubernetes resource labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


578
579
580
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 578

def labels
  @labels
end

#nameString

Identifier. The resource name (full URI of the resource) following the standard naming scheme: "projects/project/locations/location/ flagAttributes/flag_attribute_id" Corresponds to the JSON property name

Returns:

  • (String)


585
586
587
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 585

def name
  @name
end

#uidString

Output only. The unique identifier of the resource. UID is unique in the time and space for this resource within the scope of the service. It is typically generated by the server on successful creation of a resource and must not be changed. UID is used to uniquely identify resources with resource name reuses. This should be a UUID4. Corresponds to the JSON property uid

Returns:

  • (String)


594
595
596
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 594

def uid
  @uid
end

#update_timeString

Output only. The timestamp when the resource was last updated. Any change to the resource made by users must refresh this value. Changes to a resource made by the service should refresh this value. Corresponds to the JSON property updateTime

Returns:

  • (String)


601
602
603
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 601

def update_time
  @update_time
end

#value_typeString

Optional. Immutable. Deprecated: Use attribute_value_type instead. Type of the attribute. Corresponds to the JSON property valueType

Returns:

  • (String)


607
608
609
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 607

def value_type
  @value_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



614
615
616
617
618
619
620
621
622
623
624
625
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 614

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @attribute_value_type = args[:attribute_value_type] if args.key?(:attribute_value_type)
  @create_time = args[:create_time] if args.key?(:create_time)
  @etag = args[:etag] if args.key?(:etag)
  @key = args[:key] if args.key?(:key)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @value_type = args[:value_type] if args.key?(:value_type)
end