Class: Google::Apis::SaasservicemgmtV1beta1::FlagRelease
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1beta1::FlagRelease
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb
Overview
A collection of FlagRevisions.
Instance Attribute Summary collapse
-
#all_flags ⇒ Boolean
(also: #all_flags?)
Optional.
-
#all_flags_release ⇒ Boolean
(also: #all_flags_release?)
Optional.
-
#annotations ⇒ Hash<String,String>
Optional.
-
#create_time ⇒ String
Output only.
-
#effective_flag_revisions ⇒ Array<String>
Output only.
-
#etag ⇒ String
Output only.
-
#flag_revisions ⇒ Array<String>
Optional.
-
#flag_revisions_release ⇒ Google::Apis::SaasservicemgmtV1beta1::FlagRevisionList
Wrapper for a list of flag revisions.
-
#flag_sets ⇒ Array<String>
Optional.
-
#flag_sets_release ⇒ Google::Apis::SaasservicemgmtV1beta1::FlagSetList
Wrapper for a list of flag sets.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#obsolete_flags ⇒ Array<String>
Optional.
-
#uid ⇒ String
Output only.
-
#unit_kind ⇒ String
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FlagRelease
constructor
A new instance of FlagRelease.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FlagRelease
Returns a new instance of FlagRelease.
739 740 741 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 739 def initialize(**args) update!(**args) end |
Instance Attribute Details
#all_flags ⇒ Boolean Also known as: all_flags?
Optional. Immutable. DEPRECATED: Use all_flags_release instead. Rollout all
flags in the provided UnitKind. Only one of flag_revisions, all_flags, or
flag_sets can be set.
Corresponds to the JSON property allFlags
637 638 639 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 637 def all_flags @all_flags end |
#all_flags_release ⇒ Boolean Also known as: all_flags_release?
Optional. Immutable. Specifies the release includes all flags.
Corresponds to the JSON property allFlagsRelease
643 644 645 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 643 def all_flags_release @all_flags_release end |
#annotations ⇒ Hash<String,String>
Optional. Annotations is an unstructured key-value map stored with a resource
that may be set by external tools to store and retrieve arbitrary metadata.
They are not queryable and should be preserved when modifying objects. More
info: https://kubernetes.io/docs/user-guide/annotations
Corresponds to the JSON property annotations
652 653 654 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 652 def annotations @annotations end |
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
657 658 659 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 657 def create_time @create_time end |
#effective_flag_revisions ⇒ Array<String>
Output only. An OUTPUT_ONLY field that contains FlagRevisions to be rolled out.
This is the ultimate source of truth of what a Rollout or a UnitOperation
carries.
Corresponds to the JSON property effectiveFlagRevisions
664 665 666 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 664 def effective_flag_revisions @effective_flag_revisions end |
#etag ⇒ String
Output only. An opaque value that uniquely identifies a version or generation
of a resource. It can be used to confirm that the client and server agree on
the ordering of a resource being written.
Corresponds to the JSON property etag
671 672 673 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 671 def etag @etag end |
#flag_revisions ⇒ Array<String>
Optional. Immutable. DEPRECATED: Use flag_revisions_release instead.
FlagRevisions to be rolled out. Only one of flag_revisions, all_flags, or
flag_sets can be set. It used to be the ultimate source to truth and has been
moved to effective_flag_revisions.
Corresponds to the JSON property flagRevisions
679 680 681 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 679 def flag_revisions @flag_revisions end |
#flag_revisions_release ⇒ Google::Apis::SaasservicemgmtV1beta1::FlagRevisionList
Wrapper for a list of flag revisions.
Corresponds to the JSON property flagRevisionsRelease
684 685 686 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 684 def flag_revisions_release @flag_revisions_release end |
#flag_sets ⇒ Array<String>
Optional. Immutable. DEPRECATED: Use flag_sets_release instead. Flag sets to
be rolled out. Only one of flag_revisions, all_flags, or flag_sets can be set.
Corresponds to the JSON property flagSets
690 691 692 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 690 def flag_sets @flag_sets end |
#flag_sets_release ⇒ Google::Apis::SaasservicemgmtV1beta1::FlagSetList
Wrapper for a list of flag sets.
Corresponds to the JSON property flagSetsRelease
695 696 697 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 695 def flag_sets_release @flag_sets_release end |
#labels ⇒ Hash<String,String>
Optional. The labels on the resource, which can be used for categorization.
similar to Kubernetes resource labels.
Corresponds to the JSON property labels
701 702 703 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 701 def labels @labels end |
#name ⇒ String
Identifier. The resource name (full URI of the resource) following the
standard naming scheme: "projects/project/locations/location/flagReleases/
flag_release_id"
Corresponds to the JSON property name
708 709 710 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 708 def name @name end |
#obsolete_flags ⇒ Array<String>
Optional. Immutable. Deprecated: Use the 'state' field in the 'Flag' resource
to manage the cleanup of flag lifecycles including removal from UnitKind and
Units. Flags to be removed from given UnitKind and all related Units. If Flag
is provided here, its FlagRevisions will be removed from UnitKind and Units.
Corresponds to the JSON property obsoleteFlags
716 717 718 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 716 def obsolete_flags @obsolete_flags end |
#uid ⇒ String
Output only. The unique identifier of the resource. UID is unique in the time
and space for this resource within the scope of the service. It is typically
generated by the server on successful creation of a resource and must not be
changed. UID is used to uniquely identify resources with resource name reuses.
This should be a UUID4.
Corresponds to the JSON property uid
725 726 727 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 725 def uid @uid end |
#unit_kind ⇒ String
Required. Immutable. The UnitKind this FlagRelease applies to.
Corresponds to the JSON property unitKind
730 731 732 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 730 def unit_kind @unit_kind end |
#update_time ⇒ String
Output only. The timestamp when the resource was last updated. Any change to
the resource made by users must refresh this value. Changes to a resource made
by the service should refresh this value.
Corresponds to the JSON property updateTime
737 738 739 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 737 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 744 def update!(**args) @all_flags = args[:all_flags] if args.key?(:all_flags) @all_flags_release = args[:all_flags_release] if args.key?(:all_flags_release) @annotations = args[:annotations] if args.key?(:annotations) @create_time = args[:create_time] if args.key?(:create_time) @effective_flag_revisions = args[:effective_flag_revisions] if args.key?(:effective_flag_revisions) @etag = args[:etag] if args.key?(:etag) @flag_revisions = args[:flag_revisions] if args.key?(:flag_revisions) @flag_revisions_release = args[:flag_revisions_release] if args.key?(:flag_revisions_release) @flag_sets = args[:flag_sets] if args.key?(:flag_sets) @flag_sets_release = args[:flag_sets_release] if args.key?(:flag_sets_release) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @obsolete_flags = args[:obsolete_flags] if args.key?(:obsolete_flags) @uid = args[:uid] if args.key?(:uid) @unit_kind = args[:unit_kind] if args.key?(:unit_kind) @update_time = args[:update_time] if args.key?(:update_time) end |