Class: Google::Apis::SaasservicemgmtV1beta1::FlagRevision
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1beta1::FlagRevision
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb
Overview
A snapshot of the EvaluationSpec for the Flag.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#create_time ⇒ String
Output only.
-
#etag ⇒ String
Output only.
-
#evaluation_spec ⇒ Google::Apis::SaasservicemgmtV1beta1::EvaluationSpec
EvaluationSpec holds rules for evaluating the value of a flag.
-
#flag ⇒ String
Required.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#snapshot ⇒ Google::Apis::SaasservicemgmtV1beta1::Flag
Represents a single Flag.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FlagRevision
constructor
A new instance of FlagRevision.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FlagRevision
Returns a new instance of FlagRevision.
858 859 860 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 858 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Annotations is an unstructured key-value map stored with a resource
that may be set by external tools to store and retrieve arbitrary metadata.
They are not queryable and should be preserved when modifying objects. More
info: https://kubernetes.io/docs/user-guide/annotations
Corresponds to the JSON property annotations
800 801 802 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 800 def annotations @annotations end |
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
805 806 807 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 805 def create_time @create_time end |
#etag ⇒ String
Output only. An opaque value that uniquely identifies a version or generation
of a resource. It can be used to confirm that the client and server agree on
the ordering of a resource being written.
Corresponds to the JSON property etag
812 813 814 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 812 def etag @etag end |
#evaluation_spec ⇒ Google::Apis::SaasservicemgmtV1beta1::EvaluationSpec
EvaluationSpec holds rules for evaluating the value of a flag.
Corresponds to the JSON property evaluationSpec
817 818 819 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 817 def evaluation_spec @evaluation_spec end |
#flag ⇒ String
Required. Immutable. Name of the Flag this is a revision of.
Corresponds to the JSON property flag
822 823 824 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 822 def flag @flag end |
#labels ⇒ Hash<String,String>
Optional. The labels on the resource, which can be used for categorization.
similar to Kubernetes resource labels.
Corresponds to the JSON property labels
828 829 830 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 828 def labels @labels end |
#name ⇒ String
Identifier. The resource name (full URI of the resource) following the
standard naming scheme: "projects/project/locations/location/flagRevisions/
flag_revision_id"
Corresponds to the JSON property name
835 836 837 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 835 def name @name end |
#snapshot ⇒ Google::Apis::SaasservicemgmtV1beta1::Flag
Represents a single Flag.
Corresponds to the JSON property snapshot
840 841 842 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 840 def snapshot @snapshot end |
#uid ⇒ String
Output only. The unique identifier of the resource. UID is unique in the time
and space for this resource within the scope of the service. It is typically
generated by the server on successful creation of a resource and must not be
changed. UID is used to uniquely identify resources with resource name reuses.
This should be a UUID4.
Corresponds to the JSON property uid
849 850 851 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 849 def uid @uid end |
#update_time ⇒ String
Output only. The timestamp when the resource was last updated. Any change to
the resource made by users must refresh this value. Changes to a resource made
by the service should refresh this value.
Corresponds to the JSON property updateTime
856 857 858 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 856 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
863 864 865 866 867 868 869 870 871 872 873 874 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 863 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @create_time = args[:create_time] if args.key?(:create_time) @etag = args[:etag] if args.key?(:etag) @evaluation_spec = args[:evaluation_spec] if args.key?(:evaluation_spec) @flag = args[:flag] if args.key?(:flag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @snapshot = args[:snapshot] if args.key?(:snapshot) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |