Class: Google::Apis::SaasservicemgmtV1beta1::FlagRevision

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb

Overview

A snapshot of the EvaluationSpec for the Flag.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FlagRevision

Returns a new instance of FlagRevision.



832
833
834
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 832

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Annotations is an unstructured key-value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects. More info: https://kubernetes.io/docs/user-guide/annotations Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


774
775
776
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 774

def annotations
  @annotations
end

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


779
780
781
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 779

def create_time
  @create_time
end

#etagString

Output only. An opaque value that uniquely identifies a version or generation of a resource. It can be used to confirm that the client and server agree on the ordering of a resource being written. Corresponds to the JSON property etag

Returns:

  • (String)


786
787
788
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 786

def etag
  @etag
end

#evaluation_specGoogle::Apis::SaasservicemgmtV1beta1::EvaluationSpec

EvaluationSpec holds rules for evaluating the value of a flag. Corresponds to the JSON property evaluationSpec



791
792
793
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 791

def evaluation_spec
  @evaluation_spec
end

#flagString

Required. Immutable. Name of the Flag this is a revision of. Corresponds to the JSON property flag

Returns:

  • (String)


796
797
798
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 796

def flag
  @flag
end

#labelsHash<String,String>

Optional. The labels on the resource, which can be used for categorization. similar to Kubernetes resource labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


802
803
804
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 802

def labels
  @labels
end

#nameString

Identifier. The resource name (full URI of the resource) following the standard naming scheme: "projects/project/locations/location/flagRevisions/ flag_revision_id" Corresponds to the JSON property name

Returns:

  • (String)


809
810
811
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 809

def name
  @name
end

#snapshotGoogle::Apis::SaasservicemgmtV1beta1::Flag

Represents a single Flag. Corresponds to the JSON property snapshot



814
815
816
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 814

def snapshot
  @snapshot
end

#uidString

Output only. The unique identifier of the resource. UID is unique in the time and space for this resource within the scope of the service. It is typically generated by the server on successful creation of a resource and must not be changed. UID is used to uniquely identify resources with resource name reuses. This should be a UUID4. Corresponds to the JSON property uid

Returns:

  • (String)


823
824
825
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 823

def uid
  @uid
end

#update_timeString

Output only. The timestamp when the resource was last updated. Any change to the resource made by users must refresh this value. Changes to a resource made by the service should refresh this value. Corresponds to the JSON property updateTime

Returns:

  • (String)


830
831
832
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 830

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



837
838
839
840
841
842
843
844
845
846
847
848
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 837

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @create_time = args[:create_time] if args.key?(:create_time)
  @etag = args[:etag] if args.key?(:etag)
  @evaluation_spec = args[:evaluation_spec] if args.key?(:evaluation_spec)
  @flag = args[:flag] if args.key?(:flag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @snapshot = args[:snapshot] if args.key?(:snapshot)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end