Class: Google::Apis::SaasservicemgmtV1beta1::FlagVariant
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1beta1::FlagVariant
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb
Overview
Variant is an identifier for a value (name assigned to a value).
Instance Attribute Summary collapse
-
#boolean_value ⇒ Boolean
(also: #boolean_value?)
Optional.
-
#description ⇒ String
Optional.
-
#double_value ⇒ Float
Optional.
-
#id ⇒ String
Required.
-
#integer_value ⇒ Fixnum
Optional.
-
#string_value ⇒ String
Optional.
-
#tracking_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FlagVariant
constructor
A new instance of FlagVariant.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FlagVariant
Returns a new instance of FlagVariant.
977 978 979 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 977 def initialize(**args) update!(**args) end |
Instance Attribute Details
#boolean_value ⇒ Boolean Also known as: boolean_value?
Optional. Boolean variant value.
Corresponds to the JSON property booleanValue
941 942 943 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 941 def boolean_value @boolean_value end |
#description ⇒ String
Optional. A human-readable description of what this variant does or represents.
Corresponds to the JSON property description
947 948 949 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 947 def description @description end |
#double_value ⇒ Float
Optional. Double variant value.
Corresponds to the JSON property doubleValue
952 953 954 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 952 def double_value @double_value end |
#id ⇒ String
Required. Variant ID. Max length: 128 bytes.
Corresponds to the JSON property id
957 958 959 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 957 def id @id end |
#integer_value ⇒ Fixnum
Optional. Integer variant value.
Corresponds to the JSON property integerValue
962 963 964 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 962 def integer_value @integer_value end |
#string_value ⇒ String
Optional. String variant value.
Corresponds to the JSON property stringValue
967 968 969 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 967 def string_value @string_value end |
#tracking_id ⇒ String
Optional. trackingId is unique depending on name and value of the variant
within the scope of the service. It is typically generated by the server and
must not be changed. trackingId is used to uniquely identify and track
variants.
Corresponds to the JSON property trackingId
975 976 977 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 975 def tracking_id @tracking_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
982 983 984 985 986 987 988 989 990 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 982 def update!(**args) @boolean_value = args[:boolean_value] if args.key?(:boolean_value) @description = args[:description] if args.key?(:description) @double_value = args[:double_value] if args.key?(:double_value) @id = args[:id] if args.key?(:id) @integer_value = args[:integer_value] if args.key?(:integer_value) @string_value = args[:string_value] if args.key?(:string_value) @tracking_id = args[:tracking_id] if args.key?(:tracking_id) end |