Class: Google::Apis::SaasservicemgmtV1beta1::FlagVariant
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1beta1::FlagVariant
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb
Overview
Variant is an identifier for a value (name assigned to a value).
Instance Attribute Summary collapse
-
#boolean_value ⇒ Boolean
(also: #boolean_value?)
Optional.
-
#description ⇒ String
Optional.
-
#double_value ⇒ Float
Optional.
-
#id ⇒ String
Required.
-
#integer_value ⇒ Fixnum
Optional.
-
#string_value ⇒ String
Optional.
-
#tracking_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FlagVariant
constructor
A new instance of FlagVariant.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FlagVariant
Returns a new instance of FlagVariant.
951 952 953 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 951 def initialize(**args) update!(**args) end |
Instance Attribute Details
#boolean_value ⇒ Boolean Also known as: boolean_value?
Optional. Boolean variant value.
Corresponds to the JSON property booleanValue
915 916 917 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 915 def boolean_value @boolean_value end |
#description ⇒ String
Optional. A human-readable description of what this variant does or represents.
Corresponds to the JSON property description
921 922 923 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 921 def description @description end |
#double_value ⇒ Float
Optional. Double variant value.
Corresponds to the JSON property doubleValue
926 927 928 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 926 def double_value @double_value end |
#id ⇒ String
Required. Variant ID. Max length: 128 bytes.
Corresponds to the JSON property id
931 932 933 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 931 def id @id end |
#integer_value ⇒ Fixnum
Optional. Integer variant value.
Corresponds to the JSON property integerValue
936 937 938 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 936 def integer_value @integer_value end |
#string_value ⇒ String
Optional. String variant value.
Corresponds to the JSON property stringValue
941 942 943 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 941 def string_value @string_value end |
#tracking_id ⇒ String
Optional. trackingId is unique depending on name and value of the variant
within the scope of the service. It is typically generated by the server and
must not be changed. trackingId is used to uniquely identify and track
variants.
Corresponds to the JSON property trackingId
949 950 951 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 949 def tracking_id @tracking_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
956 957 958 959 960 961 962 963 964 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 956 def update!(**args) @boolean_value = args[:boolean_value] if args.key?(:boolean_value) @description = args[:description] if args.key?(:description) @double_value = args[:double_value] if args.key?(:double_value) @id = args[:id] if args.key?(:id) @integer_value = args[:integer_value] if args.key?(:integer_value) @string_value = args[:string_value] if args.key?(:string_value) @tracking_id = args[:tracking_id] if args.key?(:tracking_id) end |