Class: Google::Apis::SaasservicemgmtV1beta1::ListFlagAttributesResponse
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1beta1::ListFlagAttributesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb
Overview
The response structure for the ListFlagAttributes method.
Instance Attribute Summary collapse
-
#flag_attributes ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::FlagAttribute>
The resulting flag attributes.
-
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent ListFlagAttributes call to list the next page.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListFlagAttributesResponse
constructor
A new instance of ListFlagAttributesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListFlagAttributesResponse
Returns a new instance of ListFlagAttributesResponse.
1087 1088 1089 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1087 def initialize(**args) update!(**args) end |
Instance Attribute Details
#flag_attributes ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::FlagAttribute>
The resulting flag attributes.
Corresponds to the JSON property flagAttributes
1073 1074 1075 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1073 def flag_attributes @flag_attributes end |
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent
ListFlagAttributes call to list the next page. If empty, there are no more
pages.
Corresponds to the JSON property nextPageToken
1080 1081 1082 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1080 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1085 1086 1087 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1085 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1092 1093 1094 1095 1096 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1092 def update!(**args) @flag_attributes = args[:flag_attributes] if args.key?(:flag_attributes) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |