Class: Google::Apis::SaasservicemgmtV1beta1::ListFlagReleasesResponse
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1beta1::ListFlagReleasesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb
Overview
The response structure for the ListFlagReleases method.
Instance Attribute Summary collapse
-
#flag_releases ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::FlagRelease>
The resulting flag releases.
-
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent ListFlagReleases call to list the next page.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListFlagReleasesResponse
constructor
A new instance of ListFlagReleasesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListFlagReleasesResponse
Returns a new instance of ListFlagReleasesResponse.
1119 1120 1121 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1119 def initialize(**args) update!(**args) end |
Instance Attribute Details
#flag_releases ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::FlagRelease>
The resulting flag releases.
Corresponds to the JSON property flagReleases
1106 1107 1108 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1106 def flag_releases @flag_releases end |
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent
ListFlagReleases call to list the next page. If empty, there are no more pages.
Corresponds to the JSON property nextPageToken
1112 1113 1114 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1112 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1117 1118 1119 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1117 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1124 1125 1126 1127 1128 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1124 def update!(**args) @flag_releases = args[:flag_releases] if args.key?(:flag_releases) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |