Class: Google::Apis::SaasservicemgmtV1beta1::ListFlagReleasesResponse
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1beta1::ListFlagReleasesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb
Overview
The response structure for the ListFlagReleases method.
Instance Attribute Summary collapse
-
#flag_releases ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::FlagRelease>
The resulting flag releases.
-
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent ListFlagReleases call to list the next page.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListFlagReleasesResponse
constructor
A new instance of ListFlagReleasesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListFlagReleasesResponse
Returns a new instance of ListFlagReleasesResponse.
1093 1094 1095 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1093 def initialize(**args) update!(**args) end |
Instance Attribute Details
#flag_releases ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::FlagRelease>
The resulting flag releases.
Corresponds to the JSON property flagReleases
1080 1081 1082 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1080 def flag_releases @flag_releases end |
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent
ListFlagReleases call to list the next page. If empty, there are no more pages.
Corresponds to the JSON property nextPageToken
1086 1087 1088 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1086 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1091 1092 1093 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1091 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1098 1099 1100 1101 1102 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1098 def update!(**args) @flag_releases = args[:flag_releases] if args.key?(:flag_releases) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |