Class: Google::Apis::SaasservicemgmtV1beta1::ListFlagRevisionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1beta1::ListFlagRevisionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb
Overview
The response structure for the ListFlagRevisions method.
Instance Attribute Summary collapse
-
#flag_revisions ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::FlagRevision>
The resulting flag revisions.
-
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent ListFlagRevisions call to list the next page.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListFlagRevisionsResponse
constructor
A new instance of ListFlagRevisionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListFlagRevisionsResponse
Returns a new instance of ListFlagRevisionsResponse.
1152 1153 1154 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1152 def initialize(**args) update!(**args) end |
Instance Attribute Details
#flag_revisions ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::FlagRevision>
The resulting flag revisions.
Corresponds to the JSON property flagRevisions
1138 1139 1140 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1138 def flag_revisions @flag_revisions end |
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent
ListFlagRevisions call to list the next page. If empty, there are no more
pages.
Corresponds to the JSON property nextPageToken
1145 1146 1147 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1145 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1150 1151 1152 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1150 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1157 1158 1159 1160 1161 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1157 def update!(**args) @flag_revisions = args[:flag_revisions] if args.key?(:flag_revisions) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |