Class: Google::Apis::SaasservicemgmtV1beta1::ListFlagRevisionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1beta1::ListFlagRevisionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb
Overview
The response structure for the ListFlagRevisions method.
Instance Attribute Summary collapse
-
#flag_revisions ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::FlagRevision>
The resulting flag revisions.
-
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent ListFlagRevisions call to list the next page.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListFlagRevisionsResponse
constructor
A new instance of ListFlagRevisionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListFlagRevisionsResponse
Returns a new instance of ListFlagRevisionsResponse.
1126 1127 1128 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1126 def initialize(**args) update!(**args) end |
Instance Attribute Details
#flag_revisions ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::FlagRevision>
The resulting flag revisions.
Corresponds to the JSON property flagRevisions
1112 1113 1114 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1112 def flag_revisions @flag_revisions end |
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent
ListFlagRevisions call to list the next page. If empty, there are no more
pages.
Corresponds to the JSON property nextPageToken
1119 1120 1121 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1119 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1124 1125 1126 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1124 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1131 1132 1133 1134 1135 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1131 def update!(**args) @flag_revisions = args[:flag_revisions] if args.key?(:flag_revisions) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |