Class: Google::Apis::SaasservicemgmtV1beta1::ListUnitKindsResponse
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1beta1::ListUnitKindsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb
Overview
The response structure for the ListUnitKinds method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent ListUnitKinds call to list the next page.
-
#unit_kinds ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::UnitKind>
The resulting unit kinds.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListUnitKindsResponse
constructor
A new instance of ListUnitKindsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListUnitKindsResponse
Returns a new instance of ListUnitKindsResponse.
1375 1376 1377 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1375 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent ListUnitKinds
call to list the next page. If empty, there are no more pages.
Corresponds to the JSON property nextPageToken
1363 1364 1365 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1363 def next_page_token @next_page_token end |
#unit_kinds ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::UnitKind>
The resulting unit kinds.
Corresponds to the JSON property unitKinds
1368 1369 1370 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1368 def unit_kinds @unit_kinds end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1373 1374 1375 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1373 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1380 1381 1382 1383 1384 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1380 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unit_kinds = args[:unit_kinds] if args.key?(:unit_kinds) @unreachable = args[:unreachable] if args.key?(:unreachable) end |