Class: Google::Apis::SaasservicemgmtV1beta1::ListUnitsResponse
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1beta1::ListUnitsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb
Overview
The response structure for the ListUnits method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent ListUnits call to list the next page.
-
#units ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::Unit>
The resulting units.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListUnitsResponse
constructor
A new instance of ListUnitsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListUnitsResponse
Returns a new instance of ListUnitsResponse.
1440 1441 1442 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1440 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent ListUnits call
to list the next page. If empty, there are no more pages.
Corresponds to the JSON property nextPageToken
1428 1429 1430 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1428 def next_page_token @next_page_token end |
#units ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::Unit>
The resulting units.
Corresponds to the JSON property units
1433 1434 1435 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1433 def units @units end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
1438 1439 1440 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1438 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1445 1446 1447 1448 1449 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1445 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @units = args[:units] if args.key?(:units) @unreachable = args[:unreachable] if args.key?(:unreachable) end |