Class: Google::Apis::SaasservicemgmtV1beta1::Release

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb

Overview

A new version to be propagated and deployed to units. This includes pointers to packaged blueprints for actuation (e.g Helm or Terraform configuration packages) via artifact registry.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Release

Returns a new instance of Release.



1645
1646
1647
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1645

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Annotations is an unstructured key-value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects. More info: https://kubernetes.io/docs/user-guide/annotations Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


1560
1561
1562
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1560

def annotations
  @annotations
end

#application_template_componentGoogle::Apis::SaasservicemgmtV1beta1::ComponentRef

ComponentRef represents a reference to a component resource. Next ID: 4 Corresponds to the JSON property applicationTemplateComponent



1565
1566
1567
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1565

def application_template_component
  @application_template_component
end

#blueprintGoogle::Apis::SaasservicemgmtV1beta1::Blueprint

Blueprints are OCI Images that contain all of the artifacts needed to provision a unit. Metadata such as, type of the engine used to actuate the blueprint (e.g. terraform, helm etc) and version will come from the image manifest. If the hostname is omitted, it will be assumed to be the regional path to Artifact Registry (eg. us-east1-docker.pkg.dev). Corresponds to the JSON property blueprint



1574
1575
1576
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1574

def blueprint
  @blueprint
end

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1579
1580
1581
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1579

def create_time
  @create_time
end

#etagString

Output only. An opaque value that uniquely identifies a version or generation of a resource. It can be used to confirm that the client and server agree on the ordering of a resource being written. Corresponds to the JSON property etag

Returns:

  • (String)


1586
1587
1588
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1586

def etag
  @etag
end

#input_variable_defaultsArray<Google::Apis::SaasservicemgmtV1beta1::UnitVariable>

Optional. Mapping of input variables to default values. Maximum 100 Corresponds to the JSON property inputVariableDefaults



1591
1592
1593
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1591

def input_variable_defaults
  @input_variable_defaults
end

#input_variablesArray<Google::Apis::SaasservicemgmtV1beta1::UnitVariable>

Optional. Output only. List of input variables declared on the blueprint and can be present with their values on the unit spec Corresponds to the JSON property inputVariables



1597
1598
1599
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1597

def input_variables
  @input_variables
end

#labelsHash<String,String>

Optional. The labels on the resource, which can be used for categorization. similar to Kubernetes resource labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1603
1604
1605
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1603

def labels
  @labels
end

#nameString

Identifier. The resource name (full URI of the resource) following the standard naming scheme: "projects/project/locations/location/releases/ release" Corresponds to the JSON property name

Returns:

  • (String)


1610
1611
1612
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1610

def name
  @name
end

#output_variablesArray<Google::Apis::SaasservicemgmtV1beta1::UnitVariable>

Optional. Output only. List of output variables declared on the blueprint and can be present with their values on the unit status Corresponds to the JSON property outputVariables



1616
1617
1618
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1616

def output_variables
  @output_variables
end

#release_requirementsGoogle::Apis::SaasservicemgmtV1beta1::ReleaseRequirements

Set of requirements to be fulfilled on the Unit when using this Release. Corresponds to the JSON property releaseRequirements



1621
1622
1623
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1621

def release_requirements
  @release_requirements
end

#uidString

Output only. The unique identifier of the resource. UID is unique in the time and space for this resource within the scope of the service. It is typically generated by the server on successful creation of a resource and must not be changed. UID is used to uniquely identify resources with resource name reuses. This should be a UUID4. Corresponds to the JSON property uid

Returns:

  • (String)


1630
1631
1632
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1630

def uid
  @uid
end

#unit_kindString

Required. Immutable. Reference to the UnitKind this Release corresponds to ( required and immutable once created). Corresponds to the JSON property unitKind

Returns:

  • (String)


1636
1637
1638
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1636

def unit_kind
  @unit_kind
end

#update_timeString

Output only. The timestamp when the resource was last updated. Any change to the resource made by users must refresh this value. Changes to a resource made by the service should refresh this value. Corresponds to the JSON property updateTime

Returns:

  • (String)


1643
1644
1645
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1643

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1650
1651
1652
1653
1654
1655
1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1650

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @application_template_component = args[:application_template_component] if args.key?(:application_template_component)
  @blueprint = args[:blueprint] if args.key?(:blueprint)
  @create_time = args[:create_time] if args.key?(:create_time)
  @etag = args[:etag] if args.key?(:etag)
  @input_variable_defaults = args[:input_variable_defaults] if args.key?(:input_variable_defaults)
  @input_variables = args[:input_variables] if args.key?(:input_variables)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @output_variables = args[:output_variables] if args.key?(:output_variables)
  @release_requirements = args[:release_requirements] if args.key?(:release_requirements)
  @uid = args[:uid] if args.key?(:uid)
  @unit_kind = args[:unit_kind] if args.key?(:unit_kind)
  @update_time = args[:update_time] if args.key?(:update_time)
end