Class: Google::Apis::SaasservicemgmtV1beta1::ReleaseRequirements

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb

Overview

Set of requirements to be fulfilled on the Unit when using this Release.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReleaseRequirements

Returns a new instance of ReleaseRequirements.



1653
1654
1655
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1653

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#upgradeable_from_releasesArray<String>

Optional. A list of releases from which a unit can be upgraded to this one ( optional). If left empty no constraints will be applied. When provided, unit upgrade requests to this release will check and enforce this constraint. Corresponds to the JSON property upgradeableFromReleases

Returns:

  • (Array<String>)


1651
1652
1653
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1651

def upgradeable_from_releases
  @upgradeable_from_releases
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1658
1659
1660
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1658

def update!(**args)
  @upgradeable_from_releases = args[:upgradeable_from_releases] if args.key?(:upgradeable_from_releases)
end