Class: Google::Apis::SaasservicemgmtV1beta1::RolloutControl

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb

Overview

RolloutControl provides a way to request a change to the execution of a Rollout by pausing or canceling it.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutControl

Returns a new instance of RolloutControl.



1902
1903
1904
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1902

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

Required. Action to be performed on the Rollout. The default behavior is to run the rollout until it naturally reaches a terminal state. Corresponds to the JSON property action

Returns:

  • (String)


1894
1895
1896
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1894

def action
  @action
end

#run_paramsGoogle::Apis::SaasservicemgmtV1beta1::RunRolloutActionParams

Parameters for the RUN action controlling the behavior of the rollout when it is resumed from a PAUSED state. Corresponds to the JSON property runParams



1900
1901
1902
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1900

def run_params
  @run_params
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1907
1908
1909
1910
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 1907

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @run_params = args[:run_params] if args.key?(:run_params)
end