Class: Google::Apis::SaasservicemgmtV1beta1::RunRolloutActionParams
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1beta1::RunRolloutActionParams
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb
Overview
Parameters for the RUN action controlling the behavior of the rollout when it is resumed from a PAUSED state.
Instance Attribute Summary collapse
-
#retry_failed_operations ⇒ Boolean
(also: #retry_failed_operations?)
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RunRolloutActionParams
constructor
A new instance of RunRolloutActionParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RunRolloutActionParams
Returns a new instance of RunRolloutActionParams.
2069 2070 2071 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2069 def initialize(**args) update!(**args) end |
Instance Attribute Details
#retry_failed_operations ⇒ Boolean Also known as: retry_failed_operations?
Required. If true, the rollout will retry failed operations when resumed. This
is applicable only the current state of the Rollout is PAUSED and the
requested action is RUN.
Corresponds to the JSON property retryFailedOperations
2066 2067 2068 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2066 def retry_failed_operations @retry_failed_operations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2074 2075 2076 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2074 def update!(**args) @retry_failed_operations = args[:retry_failed_operations] if args.key?(:retry_failed_operations) end |