Class: Google::Apis::SaasservicemgmtV1beta1::Saas
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1beta1::Saas
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb
Overview
Saas is a representation of a SaaS service managed by the Producer.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#application_template ⇒ Google::Apis::SaasservicemgmtV1beta1::CompositeRef
CompositeRef represents a reference to a composite resource.
-
#blueprint_repo ⇒ String
Output only.
-
#conditions ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::SaasCondition>
Output only.
-
#create_time ⇒ String
Output only.
-
#error ⇒ Google::Apis::SaasservicemgmtV1beta1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#etag ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#locations ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::Location>
Optional.
-
#name ⇒ String
Identifier.
-
#state ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Saas
constructor
A new instance of Saas.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Saas
Returns a new instance of Saas.
2170 2171 2172 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2170 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Annotations is an unstructured key-value map stored with a resource
that may be set by external tools to store and retrieve arbitrary metadata.
They are not queryable and should be preserved when modifying objects. More
info: https://kubernetes.io/docs/user-guide/annotations
Corresponds to the JSON property annotations
2089 2090 2091 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2089 def annotations @annotations end |
#application_template ⇒ Google::Apis::SaasservicemgmtV1beta1::CompositeRef
CompositeRef represents a reference to a composite resource. Next ID: 4
Corresponds to the JSON property applicationTemplate
2094 2095 2096 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2094 def application_template @application_template end |
#blueprint_repo ⇒ String
Output only. Name of repository in Artifact Registry for system-generated
Blueprints, eg. Blueprints of imported ApplicationTemplates.
Corresponds to the JSON property blueprintRepo
2100 2101 2102 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2100 def blueprint_repo @blueprint_repo end |
#conditions ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::SaasCondition>
Output only. A set of conditions which indicate the various conditions this
resource can have.
Corresponds to the JSON property conditions
2106 2107 2108 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2106 def conditions @conditions end |
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
2111 2112 2113 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2111 def create_time @create_time end |
#error ⇒ Google::Apis::SaasservicemgmtV1beta1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
2121 2122 2123 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2121 def error @error end |
#etag ⇒ String
Output only. An opaque value that uniquely identifies a version or generation
of a resource. It can be used to confirm that the client and server agree on
the ordering of a resource being written.
Corresponds to the JSON property etag
2128 2129 2130 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2128 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. The labels on the resource, which can be used for categorization.
similar to Kubernetes resource labels.
Corresponds to the JSON property labels
2134 2135 2136 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2134 def labels @labels end |
#locations ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::Location>
Optional. List of locations that the service is available in. Rollout refers
to the list to generate a rollout plan.
Corresponds to the JSON property locations
2140 2141 2142 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2140 def locations @locations end |
#name ⇒ String
Identifier. The resource name (full URI of the resource) following the
standard naming scheme: "projects/project/locations/location/saas/saas"
Corresponds to the JSON property name
2146 2147 2148 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2146 def name @name end |
#state ⇒ String
Output only. State of the Saas. It is always in ACTIVE state if the
application_template is empty.
Corresponds to the JSON property state
2152 2153 2154 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2152 def state @state end |
#uid ⇒ String
Output only. The unique identifier of the resource. UID is unique in the time
and space for this resource within the scope of the service. It is typically
generated by the server on successful creation of a resource and must not be
changed. UID is used to uniquely identify resources with resource name reuses.
This should be a UUID4.
Corresponds to the JSON property uid
2161 2162 2163 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2161 def uid @uid end |
#update_time ⇒ String
Output only. The timestamp when the resource was last updated. Any change to
the resource made by users must refresh this value. Changes to a resource made
by the service should refresh this value.
Corresponds to the JSON property updateTime
2168 2169 2170 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2168 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2175 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @application_template = args[:application_template] if args.key?(:application_template) @blueprint_repo = args[:blueprint_repo] if args.key?(:blueprint_repo) @conditions = args[:conditions] if args.key?(:conditions) @create_time = args[:create_time] if args.key?(:create_time) @error = args[:error] if args.key?(:error) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @locations = args[:locations] if args.key?(:locations) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |