Class: Google::Apis::SaasservicemgmtV1beta1::Saas

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb

Overview

Saas is a representation of a SaaS service managed by the Producer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Saas

Returns a new instance of Saas.



2144
2145
2146
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2144

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Annotations is an unstructured key-value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects. More info: https://kubernetes.io/docs/user-guide/annotations Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


2063
2064
2065
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2063

def annotations
  @annotations
end

#application_templateGoogle::Apis::SaasservicemgmtV1beta1::CompositeRef

CompositeRef represents a reference to a composite resource. Next ID: 4 Corresponds to the JSON property applicationTemplate



2068
2069
2070
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2068

def application_template
  @application_template
end

#blueprint_repoString

Output only. Name of repository in Artifact Registry for system-generated Blueprints, eg. Blueprints of imported ApplicationTemplates. Corresponds to the JSON property blueprintRepo

Returns:

  • (String)


2074
2075
2076
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2074

def blueprint_repo
  @blueprint_repo
end

#conditionsArray<Google::Apis::SaasservicemgmtV1beta1::SaasCondition>

Output only. A set of conditions which indicate the various conditions this resource can have. Corresponds to the JSON property conditions



2080
2081
2082
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2080

def conditions
  @conditions
end

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2085
2086
2087
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2085

def create_time
  @create_time
end

#errorGoogle::Apis::SaasservicemgmtV1beta1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



2095
2096
2097
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2095

def error
  @error
end

#etagString

Output only. An opaque value that uniquely identifies a version or generation of a resource. It can be used to confirm that the client and server agree on the ordering of a resource being written. Corresponds to the JSON property etag

Returns:

  • (String)


2102
2103
2104
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2102

def etag
  @etag
end

#labelsHash<String,String>

Optional. The labels on the resource, which can be used for categorization. similar to Kubernetes resource labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2108
2109
2110
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2108

def labels
  @labels
end

#locationsArray<Google::Apis::SaasservicemgmtV1beta1::Location>

Optional. List of locations that the service is available in. Rollout refers to the list to generate a rollout plan. Corresponds to the JSON property locations



2114
2115
2116
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2114

def locations
  @locations
end

#nameString

Identifier. The resource name (full URI of the resource) following the standard naming scheme: "projects/project/locations/location/saas/saas" Corresponds to the JSON property name

Returns:

  • (String)


2120
2121
2122
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2120

def name
  @name
end

#stateString

Output only. State of the Saas. It is always in ACTIVE state if the application_template is empty. Corresponds to the JSON property state

Returns:

  • (String)


2126
2127
2128
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2126

def state
  @state
end

#uidString

Output only. The unique identifier of the resource. UID is unique in the time and space for this resource within the scope of the service. It is typically generated by the server on successful creation of a resource and must not be changed. UID is used to uniquely identify resources with resource name reuses. This should be a UUID4. Corresponds to the JSON property uid

Returns:

  • (String)


2135
2136
2137
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2135

def uid
  @uid
end

#update_timeString

Output only. The timestamp when the resource was last updated. Any change to the resource made by users must refresh this value. Changes to a resource made by the service should refresh this value. Corresponds to the JSON property updateTime

Returns:

  • (String)


2142
2143
2144
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2142

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
2163
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2149

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @application_template = args[:application_template] if args.key?(:application_template)
  @blueprint_repo = args[:blueprint_repo] if args.key?(:blueprint_repo)
  @conditions = args[:conditions] if args.key?(:conditions)
  @create_time = args[:create_time] if args.key?(:create_time)
  @error = args[:error] if args.key?(:error)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @locations = args[:locations] if args.key?(:locations)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end