Class: Google::Apis::SaasservicemgmtV1beta1::SaasCondition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb

Overview

SaasCondition describes the status of a Saas.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SaasCondition

Returns a new instance of SaasCondition.



2221
2222
2223
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2221

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_transition_timeString

Required. Last time the condition transited from one status to another. Corresponds to the JSON property lastTransitionTime

Returns:

  • (String)


2199
2200
2201
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2199

def last_transition_time
  @last_transition_time
end

#messageString

Required. Human readable message indicating details about the last transition. Corresponds to the JSON property message

Returns:

  • (String)


2204
2205
2206
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2204

def message
  @message
end

#reasonString

Required. Brief reason for the condition's last transition. Corresponds to the JSON property reason

Returns:

  • (String)


2209
2210
2211
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2209

def reason
  @reason
end

#statusString

Required. Status of the condition. Corresponds to the JSON property status

Returns:

  • (String)


2214
2215
2216
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2214

def status
  @status
end

#typeString

Required. Type of the condition. Corresponds to the JSON property type

Returns:

  • (String)


2219
2220
2221
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2219

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2226
2227
2228
2229
2230
2231
2232
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2226

def update!(**args)
  @last_transition_time = args[:last_transition_time] if args.key?(:last_transition_time)
  @message = args[:message] if args.key?(:message)
  @reason = args[:reason] if args.key?(:reason)
  @status = args[:status] if args.key?(:status)
  @type = args[:type] if args.key?(:type)
end