Class: Google::Apis::SaasservicemgmtV1beta1::SaasCondition
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1beta1::SaasCondition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb
Overview
SaasCondition describes the status of a Saas.
Instance Attribute Summary collapse
-
#last_transition_time ⇒ String
Required.
-
#message ⇒ String
Required.
-
#reason ⇒ String
Required.
-
#status ⇒ String
Required.
-
#type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SaasCondition
constructor
A new instance of SaasCondition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SaasCondition
Returns a new instance of SaasCondition.
2195 2196 2197 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2195 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last_transition_time ⇒ String
Required. Last time the condition transited from one status to another.
Corresponds to the JSON property lastTransitionTime
2173 2174 2175 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2173 def last_transition_time @last_transition_time end |
#message ⇒ String
Required. Human readable message indicating details about the last transition.
Corresponds to the JSON property message
2178 2179 2180 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2178 def @message end |
#reason ⇒ String
Required. Brief reason for the condition's last transition.
Corresponds to the JSON property reason
2183 2184 2185 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2183 def reason @reason end |
#status ⇒ String
Required. Status of the condition.
Corresponds to the JSON property status
2188 2189 2190 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2188 def status @status end |
#type ⇒ String
Required. Type of the condition.
Corresponds to the JSON property type
2193 2194 2195 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2193 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2200 2201 2202 2203 2204 2205 2206 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2200 def update!(**args) @last_transition_time = args[:last_transition_time] if args.key?(:last_transition_time) @message = args[:message] if args.key?(:message) @reason = args[:reason] if args.key?(:reason) @status = args[:status] if args.key?(:status) @type = args[:type] if args.key?(:type) end |