Class: Google::Apis::SaasservicemgmtV1beta1::Tenant

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb

Overview

Tenant represents the service producer side of an instance of the service created based on a request from a consumer. In a typical scenario a Tenant has a one-to-one mapping with a resource given out to a service consumer. Example: tenant: name: "projects/svc1/locations/loc/tenants/inst-068afff8" consumer_resource: "projects/gshoe/locations/loc/shoes/black-shoe"

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Tenant

Returns a new instance of Tenant.



2359
2360
2361
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2359

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Annotations is an unstructured key-value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects. More info: https://kubernetes.io/docs/user-guide/annotations Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


2301
2302
2303
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2301

def annotations
  @annotations
end

#consumer_resourceString

Optional. Immutable. A reference to the consumer resource this SaaS Tenant is representing. The relationship with a consumer resource can be used by App Lifecycle Manager for retrieving consumer-defined settings and policies such as maintenance policies (using Unified Maintenance Policy API). Corresponds to the JSON property consumerResource

Returns:

  • (String)


2309
2310
2311
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2309

def consumer_resource
  @consumer_resource
end

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2314
2315
2316
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2314

def create_time
  @create_time
end

#etagString

Output only. An opaque value that uniquely identifies a version or generation of a resource. It can be used to confirm that the client and server agree on the ordering of a resource being written. Corresponds to the JSON property etag

Returns:

  • (String)


2321
2322
2323
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2321

def etag
  @etag
end

#labelsHash<String,String>

Optional. The labels on the resource, which can be used for categorization. similar to Kubernetes resource labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2327
2328
2329
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2327

def labels
  @labels
end

#nameString

Identifier. The resource name (full URI of the resource) following the standard naming scheme: "projects/project/locations/location/tenants/ tenant" Corresponds to the JSON property name

Returns:

  • (String)


2334
2335
2336
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2334

def name
  @name
end

#saasString

Required. Immutable. A reference to the Saas that defines the product (managed service) that the producer wants to manage with App Lifecycle Manager. Part of the App Lifecycle Manager common data model. Corresponds to the JSON property saas

Returns:

  • (String)


2341
2342
2343
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2341

def saas
  @saas
end

#uidString

Output only. The unique identifier of the resource. UID is unique in the time and space for this resource within the scope of the service. It is typically generated by the server on successful creation of a resource and must not be changed. UID is used to uniquely identify resources with resource name reuses. This should be a UUID4. Corresponds to the JSON property uid

Returns:

  • (String)


2350
2351
2352
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2350

def uid
  @uid
end

#update_timeString

Output only. The timestamp when the resource was last updated. Any change to the resource made by users must refresh this value. Changes to a resource made by the service should refresh this value. Corresponds to the JSON property updateTime

Returns:

  • (String)


2357
2358
2359
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2357

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2364
2365
2366
2367
2368
2369
2370
2371
2372
2373
2374
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2364

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @consumer_resource = args[:consumer_resource] if args.key?(:consumer_resource)
  @create_time = args[:create_time] if args.key?(:create_time)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @saas = args[:saas] if args.key?(:saas)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end