Class: Google::Apis::SaasservicemgmtV1beta1::ToMapping
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1beta1::ToMapping
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb
Overview
Input variables whose values will be passed on to dependencies
Instance Attribute Summary collapse
-
#dependency ⇒ String
Required.
-
#ignore_for_lookup ⇒ Boolean
(also: #ignore_for_lookup?)
Optional.
-
#input_variable ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ToMapping
constructor
A new instance of ToMapping.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ToMapping
Returns a new instance of ToMapping.
2399 2400 2401 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2399 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dependency ⇒ String
Required. Alias of the dependency that the inputVariable will pass its value
to
Corresponds to the JSON property dependency
2385 2386 2387 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2385 def dependency @dependency end |
#ignore_for_lookup ⇒ Boolean Also known as: ignore_for_lookup?
Optional. Tells App Lifecycle Manager if this mapping should be used during
lookup or not
Corresponds to the JSON property ignoreForLookup
2391 2392 2393 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2391 def ignore_for_lookup @ignore_for_lookup end |
#input_variable ⇒ String
Required. Name of the inputVariable on the dependency
Corresponds to the JSON property inputVariable
2397 2398 2399 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2397 def input_variable @input_variable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2404 2405 2406 2407 2408 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2404 def update!(**args) @dependency = args[:dependency] if args.key?(:dependency) @ignore_for_lookup = args[:ignore_for_lookup] if args.key?(:ignore_for_lookup) @input_variable = args[:input_variable] if args.key?(:input_variable) end |