Class: Google::Apis::SaasservicemgmtV1beta1::Unit
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1beta1::Unit
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb
Overview
A unit of deployment that has its lifecycle via a CRUD API using an actuation engine under the hood (e.g. based on Terraform, Helm or a custom implementation provided by a service producer). A building block of a SaaS Tenant.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#application ⇒ String
Optional.
-
#conditions ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::UnitCondition>
Optional.
-
#create_time ⇒ String
Output only.
-
#dependencies ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::UnitDependency>
Optional.
-
#dependents ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::UnitDependency>
Optional.
-
#etag ⇒ String
Output only.
-
#flag_config_name ⇒ String
Output only.
-
#flag_revisions ⇒ Array<String>
Optional.
-
#input_variables ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::UnitVariable>
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#maintenance ⇒ Google::Apis::SaasservicemgmtV1beta1::MaintenanceSettings
Captures requested directives for performing future maintenance on the unit.
-
#management_mode ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#ongoing_operations ⇒ Array<String>
Optional.
-
#output_variables ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::UnitVariable>
Optional.
-
#pending_operations ⇒ Array<String>
Optional.
-
#release ⇒ String
Optional.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#scheduled_operations ⇒ Array<String>
Optional.
-
#state ⇒ String
Optional.
-
#system_cleanup_at ⇒ String
Optional.
-
#system_managed_state ⇒ String
Optional.
-
#tenant ⇒ String
Optional.
-
#uid ⇒ String
Output only.
-
#unit_kind ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Unit
constructor
A new instance of Unit.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Unit
Returns a new instance of Unit.
2619 2620 2621 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2619 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Annotations is an unstructured key-value map stored with a resource
that may be set by external tools to store and retrieve arbitrary metadata.
They are not queryable and should be preserved when modifying objects. More
info: https://kubernetes.io/docs/user-guide/annotations
Corresponds to the JSON property annotations
2450 2451 2452 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2450 def annotations @annotations end |
#application ⇒ String
Optional. Reference to the AppHub Application this unit belongs to. All
resources deployed in this Unit will be associated with the specified
Application.
Corresponds to the JSON property application
2457 2458 2459 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2457 def application @application end |
#conditions ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::UnitCondition>
Optional. Output only. A set of conditions which indicate the various
conditions this resource can have.
Corresponds to the JSON property conditions
2463 2464 2465 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2463 def conditions @conditions end |
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
2468 2469 2470 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2468 def create_time @create_time end |
#dependencies ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::UnitDependency>
Optional. Output only. Set of dependencies for this unit. Maximum 10.
Corresponds to the JSON property dependencies
2473 2474 2475 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2473 def dependencies @dependencies end |
#dependents ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::UnitDependency>
Optional. Output only. List of Units that depend on this unit. Unit can only
be deprovisioned if this list is empty. Maximum 1000.
Corresponds to the JSON property dependents
2479 2480 2481 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2479 def dependents @dependents end |
#etag ⇒ String
Output only. An opaque value that uniquely identifies a version or generation
of a resource. It can be used to confirm that the client and server agree on
the ordering of a resource being written.
Corresponds to the JSON property etag
2486 2487 2488 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2486 def etag @etag end |
#flag_config_name ⇒ String
Output only. This field stores the unique identifier for the flag
configuration to be used by this Unit.
Corresponds to the JSON property flagConfigName
2492 2493 2494 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2492 def flag_config_name @flag_config_name end |
#flag_revisions ⇒ Array<String>
Optional. Output only. Flag revisions used by this Unit.
Corresponds to the JSON property flagRevisions
2497 2498 2499 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2497 def flag_revisions @flag_revisions end |
#input_variables ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::UnitVariable>
Optional. Output only. Indicates the current input variables deployed by the
unit
Corresponds to the JSON property inputVariables
2503 2504 2505 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2503 def input_variables @input_variables end |
#labels ⇒ Hash<String,String>
Optional. The labels on the resource, which can be used for categorization.
similar to Kubernetes resource labels.
Corresponds to the JSON property labels
2509 2510 2511 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2509 def labels @labels end |
#maintenance ⇒ Google::Apis::SaasservicemgmtV1beta1::MaintenanceSettings
Captures requested directives for performing future maintenance on the unit.
This includes a request for the unit to skip maintenance for a period of time
and remain pinned to its current release as well as controls for postponing
maintenance scheduled in future.
Corresponds to the JSON property maintenance
2517 2518 2519 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2517 def maintenance @maintenance end |
#management_mode ⇒ String
Optional. Immutable. Indicates whether the Unit life cycle is controlled by
the user or by the system. Immutable once created.
Corresponds to the JSON property managementMode
2523 2524 2525 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2523 def management_mode @management_mode end |
#name ⇒ String
Identifier. The resource name (full URI of the resource) following the
standard naming scheme: "projects/project/locations/location/units/unit"
Corresponds to the JSON property name
2529 2530 2531 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2529 def name @name end |
#ongoing_operations ⇒ Array<String>
Optional. Output only. List of concurrent UnitOperations that are operating on
this Unit.
Corresponds to the JSON property ongoingOperations
2535 2536 2537 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2535 def ongoing_operations @ongoing_operations end |
#output_variables ⇒ Array<Google::Apis::SaasservicemgmtV1beta1::UnitVariable>
Optional. Output only. Set of key/value pairs corresponding to output
variables from execution of actuation templates. The variables are declared in
actuation configs (e.g in helm chart or terraform) and the values are fetched
and returned by the actuation engine upon completion of execution.
Corresponds to the JSON property outputVariables
2543 2544 2545 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2543 def output_variables @output_variables end |
#pending_operations ⇒ Array<String>
Optional. Output only. List of pending (wait to be executed) UnitOperations
for this unit.
Corresponds to the JSON property pendingOperations
2549 2550 2551 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2549 def pending_operations @pending_operations end |
#release ⇒ String
Optional. Output only. The current Release object for this Unit.
Corresponds to the JSON property release
2554 2555 2556 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2554 def release @release end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
2559 2560 2561 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2559 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Indicates whether the resource location satisfies Zone Separation
constraints. This is false by default.
Corresponds to the JSON property satisfiesPzs
2566 2567 2568 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2566 def satisfies_pzs @satisfies_pzs end |
#scheduled_operations ⇒ Array<String>
Optional. Output only. List of scheduled UnitOperations for this unit.
Corresponds to the JSON property scheduledOperations
2572 2573 2574 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2572 def scheduled_operations @scheduled_operations end |
#state ⇒ String
Optional. Output only. Current lifecycle state of the resource (e.g. if it's
being created or ready to use).
Corresponds to the JSON property state
2578 2579 2580 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2578 def state @state end |
#system_cleanup_at ⇒ String
Optional. Output only. If set, indicates the time when the system will start
removing the unit.
Corresponds to the JSON property systemCleanupAt
2584 2585 2586 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2584 def system_cleanup_at @system_cleanup_at end |
#system_managed_state ⇒ String
Optional. Output only. Indicates the system managed state of the unit.
Corresponds to the JSON property systemManagedState
2589 2590 2591 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2589 def system_managed_state @system_managed_state end |
#tenant ⇒ String
Optional. Reference to the Saas Tenant resource this unit belongs to. This for
example informs the maintenance policies to use for scheduling future updates
on a unit. (optional and immutable once created)
Corresponds to the JSON property tenant
2596 2597 2598 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2596 def tenant @tenant end |
#uid ⇒ String
Output only. The unique identifier of the resource. UID is unique in the time
and space for this resource within the scope of the service. It is typically
generated by the server on successful creation of a resource and must not be
changed. UID is used to uniquely identify resources with resource name reuses.
This should be a UUID4.
Corresponds to the JSON property uid
2605 2606 2607 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2605 def uid @uid end |
#unit_kind ⇒ String
Optional. Reference to the UnitKind this Unit belongs to. Immutable once set.
Corresponds to the JSON property unitKind
2610 2611 2612 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2610 def unit_kind @unit_kind end |
#update_time ⇒ String
Output only. The timestamp when the resource was last updated. Any change to
the resource made by users must refresh this value. Changes to a resource made
by the service should refresh this value.
Corresponds to the JSON property updateTime
2617 2618 2619 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2617 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2624 2625 2626 2627 2628 2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 2645 2646 2647 2648 2649 2650 2651 2652 2653 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2624 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @application = args[:application] if args.key?(:application) @conditions = args[:conditions] if args.key?(:conditions) @create_time = args[:create_time] if args.key?(:create_time) @dependencies = args[:dependencies] if args.key?(:dependencies) @dependents = args[:dependents] if args.key?(:dependents) @etag = args[:etag] if args.key?(:etag) @flag_config_name = args[:flag_config_name] if args.key?(:flag_config_name) @flag_revisions = args[:flag_revisions] if args.key?(:flag_revisions) @input_variables = args[:input_variables] if args.key?(:input_variables) @labels = args[:labels] if args.key?(:labels) @maintenance = args[:maintenance] if args.key?(:maintenance) @management_mode = args[:management_mode] if args.key?(:management_mode) @name = args[:name] if args.key?(:name) @ongoing_operations = args[:ongoing_operations] if args.key?(:ongoing_operations) @output_variables = args[:output_variables] if args.key?(:output_variables) @pending_operations = args[:pending_operations] if args.key?(:pending_operations) @release = args[:release] if args.key?(:release) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @scheduled_operations = args[:scheduled_operations] if args.key?(:scheduled_operations) @state = args[:state] if args.key?(:state) @system_cleanup_at = args[:system_cleanup_at] if args.key?(:system_cleanup_at) @system_managed_state = args[:system_managed_state] if args.key?(:system_managed_state) @tenant = args[:tenant] if args.key?(:tenant) @uid = args[:uid] if args.key?(:uid) @unit_kind = args[:unit_kind] if args.key?(:unit_kind) @update_time = args[:update_time] if args.key?(:update_time) end |