Class: Google::Apis::SaasservicemgmtV1beta1::Unit

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb

Overview

A unit of deployment that has its lifecycle via a CRUD API using an actuation engine under the hood (e.g. based on Terraform, Helm or a custom implementation provided by a service producer). A building block of a SaaS Tenant.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Unit

Returns a new instance of Unit.



2593
2594
2595
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2593

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Annotations is an unstructured key-value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects. More info: https://kubernetes.io/docs/user-guide/annotations Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


2424
2425
2426
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2424

def annotations
  @annotations
end

#applicationString

Optional. Reference to the AppHub Application this unit belongs to. All resources deployed in this Unit will be associated with the specified Application. Corresponds to the JSON property application

Returns:

  • (String)


2431
2432
2433
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2431

def application
  @application
end

#conditionsArray<Google::Apis::SaasservicemgmtV1beta1::UnitCondition>

Optional. Output only. A set of conditions which indicate the various conditions this resource can have. Corresponds to the JSON property conditions



2437
2438
2439
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2437

def conditions
  @conditions
end

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2442
2443
2444
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2442

def create_time
  @create_time
end

#dependenciesArray<Google::Apis::SaasservicemgmtV1beta1::UnitDependency>

Optional. Output only. Set of dependencies for this unit. Maximum 10. Corresponds to the JSON property dependencies



2447
2448
2449
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2447

def dependencies
  @dependencies
end

#dependentsArray<Google::Apis::SaasservicemgmtV1beta1::UnitDependency>

Optional. Output only. List of Units that depend on this unit. Unit can only be deprovisioned if this list is empty. Maximum 1000. Corresponds to the JSON property dependents



2453
2454
2455
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2453

def dependents
  @dependents
end

#etagString

Output only. An opaque value that uniquely identifies a version or generation of a resource. It can be used to confirm that the client and server agree on the ordering of a resource being written. Corresponds to the JSON property etag

Returns:

  • (String)


2460
2461
2462
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2460

def etag
  @etag
end

#flag_config_nameString

Output only. This field stores the unique identifier for the flag configuration to be used by this Unit. Corresponds to the JSON property flagConfigName

Returns:

  • (String)


2466
2467
2468
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2466

def flag_config_name
  @flag_config_name
end

#flag_revisionsArray<String>

Optional. Output only. Flag revisions used by this Unit. Corresponds to the JSON property flagRevisions

Returns:

  • (Array<String>)


2471
2472
2473
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2471

def flag_revisions
  @flag_revisions
end

#input_variablesArray<Google::Apis::SaasservicemgmtV1beta1::UnitVariable>

Optional. Output only. Indicates the current input variables deployed by the unit Corresponds to the JSON property inputVariables



2477
2478
2479
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2477

def input_variables
  @input_variables
end

#labelsHash<String,String>

Optional. The labels on the resource, which can be used for categorization. similar to Kubernetes resource labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2483
2484
2485
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2483

def labels
  @labels
end

#maintenanceGoogle::Apis::SaasservicemgmtV1beta1::MaintenanceSettings

Captures requested directives for performing future maintenance on the unit. This includes a request for the unit to skip maintenance for a period of time and remain pinned to its current release as well as controls for postponing maintenance scheduled in future. Corresponds to the JSON property maintenance



2491
2492
2493
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2491

def maintenance
  @maintenance
end

#management_modeString

Optional. Immutable. Indicates whether the Unit life cycle is controlled by the user or by the system. Immutable once created. Corresponds to the JSON property managementMode

Returns:

  • (String)


2497
2498
2499
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2497

def management_mode
  @management_mode
end

#nameString

Identifier. The resource name (full URI of the resource) following the standard naming scheme: "projects/project/locations/location/units/unit" Corresponds to the JSON property name

Returns:

  • (String)


2503
2504
2505
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2503

def name
  @name
end

#ongoing_operationsArray<String>

Optional. Output only. List of concurrent UnitOperations that are operating on this Unit. Corresponds to the JSON property ongoingOperations

Returns:

  • (Array<String>)


2509
2510
2511
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2509

def ongoing_operations
  @ongoing_operations
end

#output_variablesArray<Google::Apis::SaasservicemgmtV1beta1::UnitVariable>

Optional. Output only. Set of key/value pairs corresponding to output variables from execution of actuation templates. The variables are declared in actuation configs (e.g in helm chart or terraform) and the values are fetched and returned by the actuation engine upon completion of execution. Corresponds to the JSON property outputVariables



2517
2518
2519
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2517

def output_variables
  @output_variables
end

#pending_operationsArray<String>

Optional. Output only. List of pending (wait to be executed) UnitOperations for this unit. Corresponds to the JSON property pendingOperations

Returns:

  • (Array<String>)


2523
2524
2525
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2523

def pending_operations
  @pending_operations
end

#releaseString

Optional. Output only. The current Release object for this Unit. Corresponds to the JSON property release

Returns:

  • (String)


2528
2529
2530
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2528

def release
  @release
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


2533
2534
2535
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2533

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Indicates whether the resource location satisfies Zone Separation constraints. This is false by default. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


2540
2541
2542
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2540

def satisfies_pzs
  @satisfies_pzs
end

#scheduled_operationsArray<String>

Optional. Output only. List of scheduled UnitOperations for this unit. Corresponds to the JSON property scheduledOperations

Returns:

  • (Array<String>)


2546
2547
2548
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2546

def scheduled_operations
  @scheduled_operations
end

#stateString

Optional. Output only. Current lifecycle state of the resource (e.g. if it's being created or ready to use). Corresponds to the JSON property state

Returns:

  • (String)


2552
2553
2554
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2552

def state
  @state
end

#system_cleanup_atString

Optional. Output only. If set, indicates the time when the system will start removing the unit. Corresponds to the JSON property systemCleanupAt

Returns:

  • (String)


2558
2559
2560
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2558

def system_cleanup_at
  @system_cleanup_at
end

#system_managed_stateString

Optional. Output only. Indicates the system managed state of the unit. Corresponds to the JSON property systemManagedState

Returns:

  • (String)


2563
2564
2565
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2563

def system_managed_state
  @system_managed_state
end

#tenantString

Optional. Reference to the Saas Tenant resource this unit belongs to. This for example informs the maintenance policies to use for scheduling future updates on a unit. (optional and immutable once created) Corresponds to the JSON property tenant

Returns:

  • (String)


2570
2571
2572
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2570

def tenant
  @tenant
end

#uidString

Output only. The unique identifier of the resource. UID is unique in the time and space for this resource within the scope of the service. It is typically generated by the server on successful creation of a resource and must not be changed. UID is used to uniquely identify resources with resource name reuses. This should be a UUID4. Corresponds to the JSON property uid

Returns:

  • (String)


2579
2580
2581
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2579

def uid
  @uid
end

#unit_kindString

Optional. Reference to the UnitKind this Unit belongs to. Immutable once set. Corresponds to the JSON property unitKind

Returns:

  • (String)


2584
2585
2586
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2584

def unit_kind
  @unit_kind
end

#update_timeString

Output only. The timestamp when the resource was last updated. Any change to the resource made by users must refresh this value. Changes to a resource made by the service should refresh this value. Corresponds to the JSON property updateTime

Returns:

  • (String)


2591
2592
2593
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2591

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2598
2599
2600
2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2598

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @application = args[:application] if args.key?(:application)
  @conditions = args[:conditions] if args.key?(:conditions)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dependencies = args[:dependencies] if args.key?(:dependencies)
  @dependents = args[:dependents] if args.key?(:dependents)
  @etag = args[:etag] if args.key?(:etag)
  @flag_config_name = args[:flag_config_name] if args.key?(:flag_config_name)
  @flag_revisions = args[:flag_revisions] if args.key?(:flag_revisions)
  @input_variables = args[:input_variables] if args.key?(:input_variables)
  @labels = args[:labels] if args.key?(:labels)
  @maintenance = args[:maintenance] if args.key?(:maintenance)
  @management_mode = args[:management_mode] if args.key?(:management_mode)
  @name = args[:name] if args.key?(:name)
  @ongoing_operations = args[:ongoing_operations] if args.key?(:ongoing_operations)
  @output_variables = args[:output_variables] if args.key?(:output_variables)
  @pending_operations = args[:pending_operations] if args.key?(:pending_operations)
  @release = args[:release] if args.key?(:release)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @scheduled_operations = args[:scheduled_operations] if args.key?(:scheduled_operations)
  @state = args[:state] if args.key?(:state)
  @system_cleanup_at = args[:system_cleanup_at] if args.key?(:system_cleanup_at)
  @system_managed_state = args[:system_managed_state] if args.key?(:system_managed_state)
  @tenant = args[:tenant] if args.key?(:tenant)
  @uid = args[:uid] if args.key?(:uid)
  @unit_kind = args[:unit_kind] if args.key?(:unit_kind)
  @update_time = args[:update_time] if args.key?(:update_time)
end