Class: Google::Apis::SaasservicemgmtV1beta1::UnitGroup
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1beta1::UnitGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb
Overview
UnitGroup represents a set of Units to be used by a Tenant. In pooling scenarios, the UnitGroup may be created and provisioned before the Tenant is created.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#create_time ⇒ String
Output only.
-
#etag ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UnitGroup
constructor
A new instance of UnitGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UnitGroup
Returns a new instance of UnitGroup.
3005 3006 3007 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3005 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Annotations is an unstructured key-value map stored with a resource
that may be set by external tools to store and retrieve arbitrary metadata.
They are not queryable and should be preserved when modifying objects. More
info: https://kubernetes.io/docs/user-guide/annotations
Corresponds to the JSON property annotations
2962 2963 2964 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2962 def annotations @annotations end |
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
2967 2968 2969 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2967 def create_time @create_time end |
#etag ⇒ String
Output only. An opaque value that uniquely identifies a version or generation
of a resource. It can be used to confirm that the client and server agree on
the ordering of a resource being written.
Corresponds to the JSON property etag
2974 2975 2976 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2974 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. The labels on the resource, which can be used for categorization.
similar to Kubernetes resource labels.
Corresponds to the JSON property labels
2980 2981 2982 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2980 def labels @labels end |
#name ⇒ String
Identifier. The resource name (full URI of the resource) following the
standard naming scheme: "projects/project/locations/location/unitGroups/
unitGroup"
Corresponds to the JSON property name
2987 2988 2989 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2987 def name @name end |
#uid ⇒ String
Output only. The unique identifier of the resource. UID is unique in the time
and space for this resource within the scope of the service. It is typically
generated by the server on successful creation of a resource and must not be
changed. UID is used to uniquely identify resources with resource name reuses.
This should be a UUID4.
Corresponds to the JSON property uid
2996 2997 2998 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2996 def uid @uid end |
#update_time ⇒ String
Output only. The timestamp when the resource was last updated. Any change to
the resource made by users must refresh this value. Changes to a resource made
by the service should refresh this value.
Corresponds to the JSON property updateTime
3003 3004 3005 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3003 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3010 3011 3012 3013 3014 3015 3016 3017 3018 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3010 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @create_time = args[:create_time] if args.key?(:create_time) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |