Class: Google::Apis::SaasservicemgmtV1beta1::UnitGroupOperation
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1beta1::UnitGroupOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb
Overview
UnitGroupOperation represents an operation on a UnitGroup.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#create_time ⇒ String
Output only.
-
#etag ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UnitGroupOperation
constructor
A new instance of UnitGroupOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UnitGroupOperation
Returns a new instance of UnitGroupOperation.
3074 3075 3076 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3074 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Annotations is an unstructured key-value map stored with a resource
that may be set by external tools to store and retrieve arbitrary metadata.
They are not queryable and should be preserved when modifying objects. More
info: https://kubernetes.io/docs/user-guide/annotations
Corresponds to the JSON property annotations
3031 3032 3033 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3031 def annotations @annotations end |
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
3036 3037 3038 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3036 def create_time @create_time end |
#etag ⇒ String
Output only. An opaque value that uniquely identifies a version or generation
of a resource. It can be used to confirm that the client and server agree on
the ordering of a resource being written.
Corresponds to the JSON property etag
3043 3044 3045 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3043 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. The labels on the resource, which can be used for categorization.
similar to Kubernetes resource labels.
Corresponds to the JSON property labels
3049 3050 3051 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3049 def labels @labels end |
#name ⇒ String
Identifier. The resource name (full URI of the resource) following the
standard naming scheme: "projects/project/locations/location/
unitGroupOperations/unitGroupOperation"
Corresponds to the JSON property name
3056 3057 3058 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3056 def name @name end |
#uid ⇒ String
Output only. The unique identifier of the resource. UID is unique in the time
and space for this resource within the scope of the service. It is typically
generated by the server on successful creation of a resource and must not be
changed. UID is used to uniquely identify resources with resource name reuses.
This should be a UUID4.
Corresponds to the JSON property uid
3065 3066 3067 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3065 def uid @uid end |
#update_time ⇒ String
Output only. The timestamp when the resource was last updated. Any change to
the resource made by users must refresh this value. Changes to a resource made
by the service should refresh this value.
Corresponds to the JSON property updateTime
3072 3073 3074 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3072 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3079 3080 3081 3082 3083 3084 3085 3086 3087 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3079 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @create_time = args[:create_time] if args.key?(:create_time) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |