Class: Google::Apis::SaasservicemgmtV1beta1::UnitKind

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb

Overview

Definition of a Unit. Units belonging to the same UnitKind are managed together; for example they follow the same release model (blueprints, versions etc.) and are typically rolled out together.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UnitKind

Returns a new instance of UnitKind.



2803
2804
2805
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2803

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Annotations is an unstructured key-value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects. More info: https://kubernetes.io/docs/user-guide/annotations Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


2711
2712
2713
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2711

def annotations
  @annotations
end

#app_paramsGoogle::Apis::SaasservicemgmtV1beta1::AppParams

AppParams contains the parameters for creating an AppHub Application. Corresponds to the JSON property appParams



2716
2717
2718
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2716

def app_params
  @app_params
end

#application_template_componentGoogle::Apis::SaasservicemgmtV1beta1::ComponentRef

ComponentRef represents a reference to a component resource. Next ID: 4 Corresponds to the JSON property applicationTemplateComponent



2721
2722
2723
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2721

def application_template_component
  @application_template_component
end

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2726
2727
2728
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2726

def create_time
  @create_time
end

#default_flag_revisionsArray<String>

Optional. Default revisions of flags for this UnitKind. Newly created units will use the flag default_flag_revisions present at the time of creation. Corresponds to the JSON property defaultFlagRevisions

Returns:

  • (Array<String>)


2732
2733
2734
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2732

def default_flag_revisions
  @default_flag_revisions
end

#default_releaseString

Optional. A reference to the Release object to use as default for creating new units of this UnitKind (optional). If not specified, a new unit must explicitly reference which release to use for its creation. Corresponds to the JSON property defaultRelease

Returns:

  • (String)


2739
2740
2741
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2739

def default_release
  @default_release
end

#dependenciesArray<Google::Apis::SaasservicemgmtV1beta1::Dependency>

Optional. Immutable. List of other unit kinds that this release will depend on. Dependencies will be automatically provisioned if not found. Maximum 10. Corresponds to the JSON property dependencies



2745
2746
2747
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2745

def dependencies
  @dependencies
end

#etagString

Output only. An opaque value that uniquely identifies a version or generation of a resource. It can be used to confirm that the client and server agree on the ordering of a resource being written. Corresponds to the JSON property etag

Returns:

  • (String)


2752
2753
2754
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2752

def etag
  @etag
end

#input_variable_mappingsArray<Google::Apis::SaasservicemgmtV1beta1::VariableMapping>

Optional. List of inputVariables for this release that will either be retrieved from a dependency’s outputVariables, or will be passed on to a dependency’s inputVariables. Maximum 100. Corresponds to the JSON property inputVariableMappings



2759
2760
2761
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2759

def input_variable_mappings
  @input_variable_mappings
end

#labelsHash<String,String>

Optional. The labels on the resource, which can be used for categorization. similar to Kubernetes resource labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2765
2766
2767
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2765

def labels
  @labels
end

#nameString

Identifier. The resource name (full URI of the resource) following the standard naming scheme: "projects/project/locations/location/unitKinds/ unitKind" Corresponds to the JSON property name

Returns:

  • (String)


2772
2773
2774
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2772

def name
  @name
end

#output_variable_mappingsArray<Google::Apis::SaasservicemgmtV1beta1::VariableMapping>

Optional. List of outputVariables for this unit kind will be passed to this unit's outputVariables. Maximum 100. Corresponds to the JSON property outputVariableMappings



2778
2779
2780
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2778

def output_variable_mappings
  @output_variable_mappings
end

#saasString

Required. Immutable. A reference to the Saas that defines the product (managed service) that the producer wants to manage with App Lifecycle Manager. Part of the App Lifecycle Manager common data model. Immutable once set. Corresponds to the JSON property saas

Returns:

  • (String)


2785
2786
2787
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2785

def saas
  @saas
end

#uidString

Output only. The unique identifier of the resource. UID is unique in the time and space for this resource within the scope of the service. It is typically generated by the server on successful creation of a resource and must not be changed. UID is used to uniquely identify resources with resource name reuses. This should be a UUID4. Corresponds to the JSON property uid

Returns:

  • (String)


2794
2795
2796
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2794

def uid
  @uid
end

#update_timeString

Output only. The timestamp when the resource was last updated. Any change to the resource made by users must refresh this value. Changes to a resource made by the service should refresh this value. Corresponds to the JSON property updateTime

Returns:

  • (String)


2801
2802
2803
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2801

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2808
2809
2810
2811
2812
2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 2808

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @app_params = args[:app_params] if args.key?(:app_params)
  @application_template_component = args[:application_template_component] if args.key?(:application_template_component)
  @create_time = args[:create_time] if args.key?(:create_time)
  @default_flag_revisions = args[:default_flag_revisions] if args.key?(:default_flag_revisions)
  @default_release = args[:default_release] if args.key?(:default_release)
  @dependencies = args[:dependencies] if args.key?(:dependencies)
  @etag = args[:etag] if args.key?(:etag)
  @input_variable_mappings = args[:input_variable_mappings] if args.key?(:input_variable_mappings)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @output_variable_mappings = args[:output_variable_mappings] if args.key?(:output_variable_mappings)
  @saas = args[:saas] if args.key?(:saas)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end