Class: Google::Apis::SaasservicemgmtV1beta1::VariableMapping
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1beta1::VariableMapping
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1beta1/classes.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb,
lib/google/apis/saasservicemgmt_v1beta1/representations.rb
Overview
Mapping of input variables to their respective output variable for depedenencies
Instance Attribute Summary collapse
-
#from ⇒ Google::Apis::SaasservicemgmtV1beta1::FromMapping
Output variables whose values will be passed on to dependencies Corresponds to the JSON property
from. -
#to ⇒ Google::Apis::SaasservicemgmtV1beta1::ToMapping
Input variables whose values will be passed on to dependencies Corresponds to the JSON property
to. -
#variable ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VariableMapping
constructor
A new instance of VariableMapping.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VariableMapping
Returns a new instance of VariableMapping.
3127 3128 3129 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3127 def initialize(**args) update!(**args) end |
Instance Attribute Details
#from ⇒ Google::Apis::SaasservicemgmtV1beta1::FromMapping
Output variables whose values will be passed on to dependencies
Corresponds to the JSON property from
3115 3116 3117 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3115 def from @from end |
#to ⇒ Google::Apis::SaasservicemgmtV1beta1::ToMapping
Input variables whose values will be passed on to dependencies
Corresponds to the JSON property to
3120 3121 3122 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3120 def to @to end |
#variable ⇒ String
Required. name of the variable
Corresponds to the JSON property variable
3125 3126 3127 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3125 def variable @variable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3132 3133 3134 3135 3136 |
# File 'lib/google/apis/saasservicemgmt_v1beta1/classes.rb', line 3132 def update!(**args) @from = args[:from] if args.key?(:from) @to = args[:to] if args.key?(:to) @variable = args[:variable] if args.key?(:variable) end |